"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const controllers_1 = __importDefault(require("../../controllers"));
const utils_1 = require("../../utils");
class UpdateSetupController extends controllers_1.default {
    constructor(useCase, name, fields) {
        super();
        this.useCase = useCase;
        this.name = name;
        this.fields = fields;
    }
    handler(httpRequest) {
        return __awaiter(this, void 0, void 0, function* () {
            const setupInfo = (0, utils_1.setupInfoBuilder)(this.fields, httpRequest.body);
            const response = yield this.useCase.exec(httpRequest.params.id, setupInfo);
            if (response.notFound) {
                return {
                    statusCode: this.notFound(),
                    message: `Could not find the ${this.name.toLowerCase()} you want to update.`,
                };
            }
            if (response.hasTransaction) {
                return {
                    statusCode: this.clientError(),
                    message: `Can not update ${this.name.toLowerCase()} that had transaction.`,
                };
            }
            if (response.failedToUpdate) {
                return {
                    statusCode: this.internalError(),
                    message: `Failed to update ${this.name}.`,
                };
            }
            return {
                statusCode: this.ok(),
                message: `${this.name} successfully updated.`,
            };
        });
    }
}
exports.default = UpdateSetupController;
//# sourceMappingURL=update.setup.controller.js.map