export declare enum FeatureType {
    Inventory = 1,
    InventoryPurchase = 2,
    InventorySales = 3,
    Loyalty = 4,
    Subscription = 5
}
export declare enum PermissionType {
    Dashboard = "dashboard",
    Inventory = "inventory",
    Sales = "sales",
    Purchase = "purchase",
    Loyalty = "loyalty",
    Subscription = "subscription",
    More = "more",
    Report = "report",
    Setting = "setting",
    POS = "pos",
    KDS = "kds",
    ATO = "ato"
}
export declare enum ActionType {
    Read = "read",
    Write = "write",
    IssuedDocument = "issue_document",
    ClosedDocument = "closed_document",
    VoidDocument = "void_document",
    ReceivePurchaseOrder = "receive_purchase_order",
    InvoicePurchaseOrder = "invoice_purchase_order",
    ShipReturnPurchaseOrder = "ship_return_purchase_order",
    CreditMemoReturnPurchaseOrder = "credit_memo_return_purchase_order",
    ApplyToPurchaseInvoices = "apply_to_purchase_invoices",
    ShipSalesOrder = "ship_sales_order",
    InvoiceSalesOrder = "invoice_sales_order",
    ReceiveSalesOrder = "receive_sales_order",
    CreditMemoSalesReturnOrder = "credit_memo_sales_return_order",
    ApplyToSalesInvoices = "apply_to_sales_invoices",
    ShipTransferOrder = "ship_transfer_order",
    ReceiveTransferOrder = "receive_transfer_order"
}
export declare enum UserRoleTypeCode {
    AppAdmin = 1,
    POSRetail = 2,
    POSRestaurant = 3,
    POSKDS = 4,
    POSATO = 5
}
export declare const SharePermission: {
    inventory: {
        itemVariant: number;
        item: number;
        compositeItem: number;
        inventoryAdjustment: number;
        transferOrder: number;
        transferShipment: number;
        transferReceipt: number;
    };
    sales: {
        customer: number;
        salesperson: number;
        salesQuote: number;
        salesInvoice: number;
        salesCreditMemo: number;
        cashReceipt: number;
        cashReceiptRefund: number;
    };
    salesOrder: {
        salesOrder: number;
        salesReturnOrder: number;
        salesShipment: number;
        salesReceipt: number;
    };
    purchase: {
        vendor: number;
        purchaseQuote: number;
        purchaseOrder: number;
        purchaseReturnOrder: number;
        purchaseReceive: number;
        purchaseInvoice: number;
        purchaseShipment: number;
        purchaseCreditMemo: number;
        paymentMade: number;
        paymentRefund: number;
    };
    report: {
        payable: {
            reportCode: number;
            sub: {
                purchaseOrderSummary: number;
                purchaseOrderDetails: number;
                purchaseInvoiceSummary: number;
                purchaseInvoiceDetails: number;
                vendorStatementSummary: number;
                paymentMade: number;
                paymentRefund: number;
            };
        };
        purchase: {
            reportCode: number;
            sub: {
                purchaseReceiveSummary: number;
                purchaseReceiveDetails: number;
                purchaseReturnOrderSummary: number;
                purchaseReturnOrderDetails: number;
                purchaseShipmentSummary: number;
                purchaseShipmentDetails: number;
                purchaseCreditMemoSummary: number;
                purchaseCreditMemoDetails: number;
            };
        };
        receivables: {
            reportCode: number;
            sub: {
                salesOrderSummary: number;
                salesOrderDetails: number;
                salesInvoiceSummary: number;
                salesInvoiceDetails: number;
                customerStatementSummary: number;
                cashReceipt: number;
                cashReceiptRefund: number;
            };
        };
        sales: {
            reportCode: number;
            sub: {
                salesReceiveSummary: number;
                salesReceiveDetails: number;
                salesReturnOrderSummary: number;
                salesReturnOrderDetails: number;
                salesShipmentSummary: number;
                salesShipmentDetails: number;
                salesCreditMemoSummary: number;
                salesCreditMemoDetails: number;
            };
        };
    };
    more: {
        approvalRequest: number;
        BankReconciles: number;
    };
    settings: {
        companyProfile: number;
        userRole: number;
        warehouse: number;
        branch: number;
        currencies: number;
        tax: number;
        bankAccount: number;
        documentNoSeries: number;
        preference: number;
        salesChannel: number;
        paymentMethod: number;
    };
};
export declare const SharePOSPermission: {
    pos: {
        userRole: number;
        device: number;
    };
    sales: {
        shift: number;
        item: number;
        customer: number;
        salesperson: number;
        salesOrder: number;
        salesReturnOrder: number;
    };
};
export declare const InventoryRetailPermission: {
    inventory: {
        itemVariant: number;
        item: number;
        compositeItem: number;
        inventoryAdjustment: number;
        transferOrder: number;
        transferShipment: number;
        transferReceipt: number;
    };
    sales: {
        salesOrder: number;
        salesReturnOrder: number;
        salesShipment: number;
        salesReceipt: number;
        customer: number;
        salesperson: number;
        salesQuote: number;
        salesInvoice: number;
        salesCreditMemo: number;
        cashReceipt: number;
        cashReceiptRefund: number;
    };
    purchase: {
        vendor: number;
        purchaseQuote: number;
        purchaseOrder: number;
        purchaseReturnOrder: number;
        purchaseReceive: number;
        purchaseInvoice: number;
        purchaseShipment: number;
        purchaseCreditMemo: number;
        paymentMade: number;
        paymentRefund: number;
    };
    more: {
        approvalRequest: number;
        BankReconciles: number;
    };
    pos: {
        userRole: number;
        device: number;
    };
    report: {
        payable: {
            reportCode: number;
            sub: {
                purchaseOrderSummary: number;
                purchaseOrderDetails: number;
                purchaseInvoiceSummary: number;
                purchaseInvoiceDetails: number;
                vendorStatementSummary: number;
                paymentMade: number;
                paymentRefund: number;
            };
        };
        purchase: {
            reportCode: number;
            sub: {
                purchaseReceiveSummary: number;
                purchaseReceiveDetails: number;
                purchaseReturnOrderSummary: number;
                purchaseReturnOrderDetails: number;
                purchaseShipmentSummary: number;
                purchaseShipmentDetails: number;
                purchaseCreditMemoSummary: number;
                purchaseCreditMemoDetails: number;
            };
        };
        receivables: {
            reportCode: number;
            sub: {
                salesOrderSummary: number;
                salesOrderDetails: number;
                salesInvoiceSummary: number;
                salesInvoiceDetails: number;
                customerStatementSummary: number;
                cashReceipt: number;
                cashReceiptRefund: number;
            };
        };
        sales: {
            reportCode: number;
            sub: {
                salesReceiveSummary: number;
                salesReceiveDetails: number;
                salesReturnOrderSummary: number;
                salesReturnOrderDetails: number;
                salesShipmentSummary: number;
                salesShipmentDetails: number;
                salesCreditMemoSummary: number;
                salesCreditMemoDetails: number;
            };
        };
    };
    settings: {
        companyProfile: number;
        userRole: number;
        warehouse: number;
        branch: number;
        currencies: number;
        tax: number;
        bankAccount: number;
        documentNoSeries: number;
        preference: number;
        salesChannel: number;
        paymentMethod: number;
    };
};
export declare const RetailPOSPermission: {
    pos: {
        floorPlan: number;
        reservation: number;
        shift: number;
        item: number;
        customer: number;
        salesperson: number;
        salesOrder: number;
        salesReturnOrder: number;
        device: number;
    };
};
export declare const LoyaltyPermission: {
    loyalty: {
        Tier: number;
        Card: number;
        Reward: number;
        Voucher: number;
        Promotion: number;
    };
    inventory: {
        item: number;
        compositeItem: number;
    };
    sales: {
        customer: number;
    };
};
export declare const SubscriptionPermission: {
    subscription: {
        addon: number;
        product: number;
        subscription: number;
    };
    sales: {
        customer: number;
        salesperson: number;
        salesQuote: number;
        salesInvoice: number;
        salesCreditMemo: number;
        cashReceipt: number;
        cashReceiptRefund: number;
    };
    more: {
        approvalRequest: number;
    };
    report: {};
    settings: {
        companyProfile: number;
        userRole: number;
        warehouse: number;
        branch: number;
        currencies: number;
        tax: number;
        bankAccount: number;
        documentNoSeries: number;
        preference: number;
        salesChannel: number;
        paymentMethod: number;
    };
};
export declare const InventoryRestaurantPermission: {
    inventory: {
        itemModifire: number;
        itemVariant: number;
        item: number;
        compositeItem: number;
        inventoryAdjustment: number;
        transferOrder: number;
        transferShipment: number;
        transferReceipt: number;
    };
    sales: {
        salesOrder: number;
        salesReturnOrder: number;
        salesShipment: number;
        salesReceipt: number;
        customer: number;
        salesperson: number;
        salesQuote: number;
        salesInvoice: number;
        salesCreditMemo: number;
        cashReceipt: number;
        cashReceiptRefund: number;
    };
    more: {
        approvalRequest: number;
        BankReconciles: number;
    };
    purchase: {
        vendor: number;
        purchaseQuote: number;
        purchaseOrder: number;
        purchaseReturnOrder: number;
        purchaseReceive: number;
        purchaseInvoice: number;
        purchaseShipment: number;
        purchaseCreditMemo: number;
        paymentMade: number;
        paymentRefund: number;
    };
    pos: {
        floorPlan: number;
        reservation: number;
        kitchenOrder: number;
        userRole: number;
        device: number;
    };
    report: {
        payable: {
            reportCode: number;
            sub: {
                purchaseOrderSummary: number;
                purchaseOrderDetails: number;
                purchaseInvoiceSummary: number;
                purchaseInvoiceDetails: number;
                vendorStatementSummary: number;
                paymentMade: number;
                paymentRefund: number;
            };
        };
        purchase: {
            reportCode: number;
            sub: {
                purchaseReceiveSummary: number;
                purchaseReceiveDetails: number;
                purchaseReturnOrderSummary: number;
                purchaseReturnOrderDetails: number;
                purchaseShipmentSummary: number;
                purchaseShipmentDetails: number;
                purchaseCreditMemoSummary: number;
                purchaseCreditMemoDetails: number;
            };
        };
        receivables: {
            reportCode: number;
            sub: {
                salesOrderSummary: number;
                salesOrderDetails: number;
                salesInvoiceSummary: number;
                salesInvoiceDetails: number;
                customerStatementSummary: number;
                cashReceipt: number;
                cashReceiptRefund: number;
            };
        };
        sales: {
            reportCode: number;
            sub: {
                salesReceiveSummary: number;
                salesReceiveDetails: number;
                salesReturnOrderSummary: number;
                salesReturnOrderDetails: number;
                salesShipmentSummary: number;
                salesShipmentDetails: number;
                salesCreditMemoSummary: number;
                salesCreditMemoDetails: number;
            };
        };
    };
    settings: {
        companyProfile: number;
        userRole: number;
        warehouse: number;
        branch: number;
        currencies: number;
        tax: number;
        bankAccount: number;
        documentNoSeries: number;
        preference: number;
        salesChannel: number;
        paymentMethod: number;
    };
};
export declare const RestaurantPOSPermission: {
    pos: {
        floorPlan: number;
        reservation: number;
        shift: number;
        item: number;
        customer: number;
        salesperson: number;
        salesOrder: number;
        salesReturnOrder: number;
        device: number;
    };
};
export declare const RestaurantKDSPermission: {
    kds: {
        device: number;
        kitchenOrder: number;
    };
};
export declare const RestaurantATOPermission: {
    ato: {
        device: number;
        item: number;
        customer: number;
        salesOrder: number;
    };
};
