import { ObjectId } from 'mongodb';
import { ISubscriptionStatusCode, Projection, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IInventoryFeature {
    storages: number;
    items: number;
    warehouses: number;
    branches: number;
    sales_order: number;
    purchase_order: number;
    multi_currency: boolean;
    sales_management: boolean;
    purchase_management: boolean;
    inventory_management: boolean;
    approval_request: boolean;
    pos: boolean;
    ios_app: boolean;
    android_app: boolean;
}
export interface IInventoryAccessibleFeature {
    dashboard: number[];
    inventory: number[];
    sales: number[];
    purchase: number[];
    reports: number[];
    settings: number[];
    more: number[];
}
export interface ILoyaltyFeature {
    storages: number;
    branches: number;
    tires: boolean;
    memberships: boolean;
    rewards: boolean;
    vouchers: boolean;
    promotions: boolean;
    ios_app: boolean;
    android_app: boolean;
}
export interface ILoyaltyAccessibleFeature {
    dashboard: number[];
    loyalty: number[];
    sales: number[];
    reports: number[];
}
export interface ISubscriptionFeature {
    storages: number;
    warehouses: number;
    branches: number;
    invoice: number;
    multi_currency: boolean;
    subscription_management: boolean;
    approval_request: boolean;
    ios_app: boolean;
    android_app: boolean;
}
export interface ISubscriptionAccessibleFeature {
    dashboard: number[];
    subscriptions: number[];
    sales: number[];
    reports: number[];
}
export interface IAppFeature extends IInventoryFeature, ILoyaltyFeature {
}
export interface IAppDocument {
    _id?: ObjectId;
    sub_product_code: string;
    sub_pricing_plan_code: string;
    feature: IInventoryFeature | ILoyaltyFeature | ISubscriptionFeature;
    accessible: IInventoryAccessibleFeature | ILoyaltyAccessibleFeature | ISubscriptionAccessibleFeature;
    status_code: ISubscriptionStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by?: ObjectId;
}
export interface IAppResult extends Partial<IAppDocument> {
}
export interface IAppInfo extends Omit<IAppDocument, BaseExtractFields> {
}
export interface IAppSpec<T> extends Partial<Record<keyof IAppResult, T>> {
}
export interface IAppUpdateDocument extends IAppSpec<Sort> {
}
export interface IAppFilter extends IAppResult {
}
export interface IAppProjection extends IAppSpec<Projection> {
}
export interface IAppSort extends IAppSpec<Sort> {
}
