import { ObjectId } from 'mongodb';
import { ApprovalDocumentTypeCode, ApprovalSetupTypeCode, ApprovalStatus, ApprovalStatusCode, Projection, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IRequestBy {
    request_by_id: ObjectId;
    request_by_name: string;
    request_date: Date;
}
export interface IApprovalAction {
    by_id: ObjectId;
    by_name: string;
    action_date: Date;
    status: ApprovalStatus;
    status_code: ApprovalStatusCode;
}
export interface IApprovalRequestDocument {
    _id?: ObjectId;
    branch_id: ObjectId;
    type_code: ApprovalSetupTypeCode;
    document_no: string;
    document_type_code: ApprovalDocumentTypeCode;
    next_approver_id: ObjectId;
    last_request_date: Date;
    requests: IRequestBy[];
    actions: IApprovalAction[];
    status_code: ApprovalStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IApprovalRequestResult extends Partial<IApprovalRequestDocument> {
}
export interface IApprovalRequestSpec<T> extends Partial<Record<keyof IApprovalRequestDocument, T>> {
}
export interface IApprovalRequestInfo extends Omit<IApprovalRequestDocument, BaseExtractFields> {
}
export interface IApprovalRequestUpdateDocument extends IApprovalRequestResult {
}
export interface IApprovalRequestFilter extends IApprovalRequestResult {
}
export interface IApprovalRequestProjection extends IApprovalRequestSpec<Projection> {
}
export interface IApprovalRequestSort extends IApprovalRequestSpec<Sort> {
}
