import { ObjectId } from 'mongodb';
import { Projection, Sort } from '../../enum';
import { EntryTypeCode, SourceTypeCode, TaxTypeCode, TransactionTaxTypeCode, VATCalculationType, VATEntryDocumentTypeCode } from '../../enum/transaction.enum';
import { BaseExtractFields } from '../base.interface';
export interface IVATEntryDocument {
    _id?: ObjectId;
    app_id: string;
    branch_id: ObjectId;
    tax_type_code: TaxTypeCode;
    txn_tax_type_code: TransactionTaxTypeCode;
    registered_tax_no?: string;
    document_date: Date;
    posting_date?: Date;
    tax_invoice_no?: string;
    document_no: string;
    document_type_code: VATEntryDocumentTypeCode;
    entry_date?: Date;
    entry_type_code: EntryTypeCode;
    source_type_code: SourceTypeCode;
    source_id: ObjectId;
    vat_calculation_type: VATCalculationType;
    currency_code: string;
    exchange_rate: number;
    amount: number;
    amount_bcy: number;
    is_reversed: boolean;
    is_settled: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IVATEntryResult extends Partial<IVATEntryDocument> {
}
export interface IVATEntrySpec<T> extends Partial<Record<keyof IVATEntryDocument, T>> {
}
export interface IVATEntryInfo extends Omit<IVATEntryDocument, BaseExtractFields> {
}
export interface IVATEntryUpdateDocument extends IVATEntryResult {
}
export interface IVATEntryFilter extends IVATEntryResult {
}
export interface IVATEntryProjection extends IVATEntrySpec<Projection> {
}
export interface IVATEntrySort extends IVATEntrySpec<Sort> {
}
