import { ObjectId } from 'mongodb';
import { CostingMethods, ItemTrackingTypeCode, ItemTypeCode, Projection, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface ICompositeItem {
    item_id: ObjectId;
    sku: string;
    barcode: string;
    item_name: string;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    quantity: number;
    is_inventory_tracking: boolean;
    tracking_type_code?: ItemTrackingTypeCode;
}
export interface IItemUnitOfMeasureDocument {
    _id?: ObjectId;
    barcode: string;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    is_default: boolean;
}
export interface IItemUnitOfMeasureResult extends Partial<IItemUnitOfMeasureDocument> {
}
export interface IItemUnitOfMeasureSpec<T> extends Partial<Record<keyof IItemUnitOfMeasureDocument, T>> {
}
export interface IItemUnitOfMeasureInfo extends Omit<IItemUnitOfMeasureDocument, BaseExtractFields> {
}
export interface IItemUnitOfMeasureUpdateDocument extends IItemUnitOfMeasureResult {
}
export interface IItemUnitOfMeasureFilter extends IItemUnitOfMeasureResult {
}
export interface IItemUnitOfMeasureProjection extends IItemUnitOfMeasureSpec<Projection> {
}
export interface IItemUnitOfMeasureSort extends IItemUnitOfMeasureSpec<Sort> {
}
export interface IBranchItemSalesPrice {
    branch_id: ObjectId;
    item_unit_of_measure_id: ObjectId;
    selling_price: number;
}
export interface IItemDocument {
    _id?: ObjectId;
    source_app_id: string;
    branches: ObjectId[];
    sku: string;
    name: string;
    description: string;
    type_code: ItemTypeCode;
    item_unit_of_measure?: IItemUnitOfMeasureDocument[];
    category_id: ObjectId;
    group_id?: ObjectId;
    class_id?: ObjectId;
    brand_id?: ObjectId;
    costing_method: CostingMethods;
    tracking_type_code?: ItemTrackingTypeCode;
    is_service_item: boolean;
    is_returnable: boolean;
    allow_for_sales: boolean;
    branch_sales_price: IBranchItemSalesPrice[];
    allow_for_purchase: boolean;
    cost_price: number;
    vat_id?: ObjectId;
    variant_id?: ObjectId;
    is_variant: boolean;
    is_variant_default: boolean;
    is_composite_item: boolean;
    composite_items?: ICompositeItem[];
    item_modifier_ids?: ObjectId[];
    is_inventory_tracking: boolean;
    prevent_negative_inventory: boolean;
    media_id?: ObjectId;
    sales_channel_codes?: string[];
    has_transaction: boolean;
    is_active: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IItemResult extends Partial<IItemDocument> {
}
export interface IItemSpec<T> extends Partial<Record<keyof IItemDocument, T>> {
}
export interface IItemInfo extends Omit<IItemDocument, BaseExtractFields> {
}
export interface IItemUpdateDocument extends IItemResult {
}
export interface IItemFilter extends IItemResult {
}
export interface IItemProjection extends IItemSpec<Projection> {
}
export interface IItemSort extends IItemSpec<Sort> {
}
