import { ObjectId } from 'mongodb';
import { EntryTypeCode, SourceTypeCode, DocumentTypeCode, Projection, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IItemLedgerEntryDocument {
    _id?: ObjectId;
    item_id: ObjectId;
    item_sku: string;
    variant_id: ObjectId;
    is_variant: boolean;
    posting_date?: string | Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    entry_type_code: EntryTypeCode;
    entry_date: string | Date;
    source_type_code: SourceTypeCode;
    source_id: string;
    document_no: string;
    document_type_code: DocumentTypeCode;
    document_date?: string | Date;
    order_id: ObjectId;
    order_type_code: DocumentTypeCode;
    order_no: string;
    order_date: string | Date;
    order_line_id: ObjectId;
    external_document_no?: string;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    base_unit_id: ObjectId;
    base_unit_name: string;
    base_unit_factor: number;
    quantity: number;
    base_quantity: number;
    remaining_quantity: number;
    currency_code: string;
    exchange_rate: number;
    price: number;
    base_price: number;
    vat_amount: number;
    amount_exclude_vat: number;
    amount: number;
    lot_no?: string;
    serial_no?: string;
    warranty_date?: Date;
    expiration_date?: Date;
    is_adjustment: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IItemLedgerEntryResult extends Partial<IItemLedgerEntryDocument> {
}
export interface IItemLedgerEntrySpec<T> extends Partial<Record<keyof IItemLedgerEntryDocument, T>> {
}
export interface IItemLedgerEntryInfo extends Omit<IItemLedgerEntryDocument, BaseExtractFields | 'entry_date'> {
}
export interface IItemLedgerEntryUpdateDocument extends IItemLedgerEntryResult {
}
export interface IItemLedgerEntryFilter extends IItemLedgerEntryResult {
}
export interface IItemLedgerEntryProjection extends IItemLedgerEntrySpec<Projection> {
}
export interface IItemLedgerEntrySort extends IItemLedgerEntrySpec<Sort> {
}
