import { ObjectId } from 'mongodb';
import { EntryTypeCode, SourceTypeCode, DocumentTypeCode, Projection, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IItemValueEntryDocument {
    _id?: ObjectId;
    type_code: EntryTypeCode;
    item_id: ObjectId;
    item_sku: string;
    variant_id: ObjectId;
    is_variant: boolean;
    item_charge_id?: ObjectId;
    is_inventory_tracking: boolean;
    posting_date?: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    entry_date: string | Date;
    entry_type_code: EntryTypeCode;
    source_type_code: SourceTypeCode;
    source_id: string;
    document_no: string;
    document_type_code: DocumentTypeCode;
    document_date: string | Date;
    order_id: ObjectId;
    order_type_code: DocumentTypeCode;
    order_no: string;
    order_date: string | Date;
    order_line_id: ObjectId;
    external_document_no?: string;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    base_unit_id: ObjectId;
    base_unit_name: string;
    base_unit_factor: number;
    quantity: number;
    base_quantity: number;
    currency_code: string;
    exchange_rate: number;
    price: number;
    base_price: number;
    vat_amount: number;
    amount_exclude_vat: number;
    amount: number;
    purchase_amount: number;
    sales_amount: number;
    discount_amount: number;
    is_adjustment: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IItemValueEntryResult extends Partial<IItemValueEntryDocument> {
}
export interface IItemValueEntrySpec<T> extends Partial<Record<keyof IItemValueEntryDocument, T>> {
}
export interface IItemValueEntryInfo extends Omit<IItemValueEntryDocument, BaseExtractFields | 'entry_date'> {
}
export interface IItemValueEntryUpdateDocument extends IItemValueEntryResult {
}
export interface IItemValueEntryFilter extends IItemValueEntryResult {
}
export interface IItemValueEntryProjection extends IItemValueEntrySpec<Projection> {
}
export interface IItemValueEntrySort extends IItemValueEntrySpec<Sort> {
}
