import { ObjectId } from 'mongodb';
import { Projection, Sort, CostingMethods, ItemTrackingTypeCode } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { IItemResult } from './item.interface';
export interface IItemAttribute {
    name: string;
    options: string[];
}
export interface IItemVariantDocument {
    _id?: ObjectId;
    source_app_id: string;
    name: string;
    description: string;
    first_attribute: IItemAttribute;
    second_attribute?: IItemAttribute;
    third_attribute?: IItemAttribute;
    branches: ObjectId[];
    image?: string;
    has_transaction: boolean;
    is_active: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IVariantInfo {
    sku: string;
    barcode: string;
    name: string;
    selling_price: number;
    cost_price: number;
    reorder_quantity: boolean;
    upc?: string;
    ean?: string;
    mpn?: string;
    isbn?: string;
    dimension_unit?: string;
    length?: number;
    width?: number;
    height?: number;
    weight?: number;
    weight_unit?: string;
    initial_stock?: number;
    image?: string;
}
export interface IItemVariantHeaderInfo {
    name: string;
    description: string;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    category_id: ObjectId;
    group_id?: ObjectId;
    classId?: ObjectId;
    brand_id?: ObjectId;
    first_attribute: IItemAttribute;
    second_attribute?: IItemAttribute;
    third_attribute?: IItemAttribute;
    costing_method: CostingMethods;
    tracking_type_code?: ItemTrackingTypeCode;
    is_service_item?: boolean;
    is_returnable: boolean;
    allow_for_sales: boolean;
    allow_for_purchase: boolean;
    vat_id?: ObjectId;
    is_inventory_tracking: boolean;
    prevent_negative_inventory: boolean;
    sales_channel_codes?: string[];
    image?: string;
    is_active: boolean;
}
export interface IItemVariantResult extends Partial<IItemVariantDocument> {
}
export interface IItemVariantWitVariantsResult extends IItemVariantResult {
    items?: IItemResult[];
}
export interface IItemVariantSpec<T> extends Partial<Record<keyof IItemVariantDocument, T>> {
}
export interface IItemVariantInfo extends Omit<IItemVariantDocument, BaseExtractFields> {
}
export interface IItemVariantUpdateDocument extends IItemVariantResult {
}
export interface IItemVariantFilter extends IItemVariantResult {
}
export interface IItemVariantProjection extends IItemVariantSpec<Projection> {
}
export interface IItemVariantSort extends IItemVariantSpec<Sort> {
}
