import { ObjectId } from 'mongodb';
import { ItemTypeCode, Projection, Sort, TransferStatusCode } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface ITransferOrderHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_date: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_ids: ObjectId[];
    from_warehouse_id: ObjectId;
    in_transit_warehouse_id: ObjectId;
    to_warehouse_id: ObjectId;
    external_document_no?: string;
    reason_id?: ObjectId;
    total_amount: number;
    status_code: TransferStatusCode;
    shipped_status_code: TransferStatusCode;
    received_status_code: TransferStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ITransferOrderHeaderResult extends Partial<ITransferOrderHeaderDocument> {
}
export interface ITransferOrderHeaderSpec<T> extends Partial<Record<keyof ITransferOrderHeaderDocument, T>> {
}
export interface ITransferOrderHeaderInfo extends Omit<ITransferOrderHeaderDocument, BaseExtractFields | 'status' | 'status_code' | 'shipped_status' | 'shipped_status_code' | 'received_status' | 'received_status_code'> {
}
export interface ITransferOrderHeaderUpdateDocument extends ITransferOrderHeaderResult {
}
export interface ITransferOrderHeaderFilter extends ITransferOrderHeaderResult {
}
export interface ITransferOrderHeaderProjection extends ITransferOrderHeaderSpec<Projection> {
}
export interface ITransferOrderHeaderSort extends ITransferOrderHeaderSpec<Sort> {
}
export interface ITransferOrderLineDocument {
    _id?: ObjectId;
    document_no: string;
    document_date: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_ids: ObjectId[];
    from_warehouse_id: ObjectId;
    in_transit_warehouse_id: ObjectId;
    to_warehouse_id: ObjectId;
    item_type_code: ItemTypeCode;
    item_id: ObjectId;
    item_sku: string;
    variant_id?: ObjectId;
    category_id: ObjectId;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    base_unit_id: ObjectId;
    base_unit_name: string;
    base_unit_factor: number;
    quantity: number;
    base_quantity: number;
    cost_price: number;
    base_cost_price: number;
    amount: number;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ITransferOrderLineResult extends Partial<ITransferOrderLineDocument> {
}
export interface ITransferOrderLineSpec<T> extends Partial<Record<keyof ITransferOrderLineDocument, T>> {
}
export interface ITransferOrderLineInfo extends Omit<ITransferOrderLineDocument, BaseExtractFields> {
}
export interface ITransferOrderLineUpdateDocument extends ITransferOrderLineResult {
}
export interface ITransferOrderLineFilter extends ITransferOrderLineResult {
}
export interface ITransferOrderLineProjection extends ITransferOrderLineSpec<Projection> {
}
export interface ITransferOrderLineSort extends ITransferOrderLineSpec<Sort> {
}
export interface ITransferShipmentHeaderDocument extends Omit<ITransferOrderHeaderDocument, 'warehouse_ids' | 'reason_id' | 'reason' | 'status' | 'status_code' | 'shipped_status' | 'shipped_status_code' | 'received_status' | 'received_status_code'> {
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
}
export interface ITransferShipmentHeaderResult extends Partial<ITransferShipmentHeaderDocument> {
}
export interface ITransferShipmentHeaderSpec<T> extends Partial<Record<keyof ITransferShipmentHeaderDocument, T>> {
}
export interface ITransferShipmentHeaderInfo extends Omit<ITransferShipmentHeaderDocument, BaseExtractFields> {
}
export interface ITransferShipmentHeaderUpdateDocument extends ITransferShipmentHeaderResult {
}
export interface ITransferShipmentHeaderFilter extends ITransferShipmentHeaderResult {
}
export interface ITransferShipmentHeaderProjection extends ITransferShipmentHeaderSpec<Projection> {
}
export interface ITransferShipmentHeaderSort extends ITransferShipmentHeaderSpec<Sort> {
}
export interface ITransferShipmentLineDocument extends Omit<ITransferOrderLineDocument, 'warehouse_ids'> {
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
    order_line_id: ObjectId;
}
export interface ITransferShipmentLineResult extends Partial<ITransferShipmentLineDocument> {
}
export interface ITransferShipmentLineSpec<T> extends Partial<Record<keyof ITransferShipmentLineDocument, T>> {
}
export interface ITransferShipmentLineInfo extends Omit<ITransferShipmentLineDocument, BaseExtractFields> {
}
export interface ITransferShipmentLineUpdateDocument extends ITransferShipmentLineResult {
}
export interface ITransferShipmentLineFilter extends ITransferShipmentLineResult {
}
export interface ITransferShipmentLineProjection extends ITransferShipmentLineSpec<Projection> {
}
export interface ITransferShipmentLineSort extends ITransferShipmentLineSpec<Sort> {
}
export interface ITransferReceiptHeaderDocument extends Omit<ITransferOrderHeaderDocument, 'warehouse_ids' | 'reason_id' | 'reason' | 'status' | 'status_code' | 'shipped_status' | 'shipped_status_code' | 'received_status' | 'received_status_code'> {
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
}
export interface ITransferReceiptHeaderResult extends Partial<ITransferReceiptHeaderDocument> {
}
export interface ITransferReceiptHeaderSpec<T> extends Partial<Record<keyof ITransferReceiptHeaderDocument, T>> {
}
export interface ITransferReceiptHeaderInfo extends Omit<ITransferReceiptHeaderDocument, BaseExtractFields> {
}
export interface ITransferReceiptHeaderUpdateDocument extends ITransferReceiptHeaderResult {
}
export interface ITransferReceiptHeaderFilter extends ITransferReceiptHeaderResult {
}
export interface ITransferReceiptHeaderProjection extends ITransferReceiptHeaderSpec<Projection> {
}
export interface ITransferReceiptHeaderSort extends ITransferReceiptHeaderSpec<Sort> {
}
export interface ITransferReceiptLineDocument extends Omit<ITransferOrderLineDocument, 'warehouse_ids'> {
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
    order_line_id: ObjectId;
}
export interface ITransferReceiptLineResult extends Partial<ITransferReceiptLineDocument> {
}
export interface ITransferReceiptLineSpec<T> extends Partial<Record<keyof ITransferReceiptLineDocument, T>> {
}
export interface ITransferReceiptLineInfo extends Omit<ITransferReceiptLineDocument, BaseExtractFields> {
}
export interface ITransferReceiptLineUpdateDocument extends ITransferReceiptLineResult {
}
export interface ITransferReceiptLineFilter extends ITransferReceiptLineResult {
}
export interface ITransferReceiptLineProjection extends ITransferReceiptLineSpec<Projection> {
}
export interface ITransferReceiptLineSort extends ITransferReceiptLineSpec<Sort> {
}
