import { ObjectId, Sort } from 'mongodb';
import { LoyaltyApplyCustomerCode, LoyaltyApplyItemCode, LoyaltyPromotionFreeTypeCode, LoyaltyPromotionStatusCode, LoyaltyPromotionTypeCode, Projection } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface ILoyaltyPromotionFreeItem {
    item_id: ObjectId;
    item_name: string;
    unit_id?: ObjectId;
    unit_name?: string;
    quantity?: number;
}
export interface ILoyaltyPromotionItemRule {
    item_id: ObjectId;
    item_name: string;
    min_quantity?: number;
    discount_percentage?: number;
    discount_amount?: number;
    free_type_code?: LoyaltyPromotionFreeTypeCode;
    free_items?: ILoyaltyPromotionFreeItem[];
}
export interface ILoyaltyPromotionItemCategoryRule {
    item_category_id: ObjectId;
    discount_percentage?: number;
    discount_amount?: number;
}
export interface ILoyaltyPromotionDocument {
    _id?: ObjectId;
    branches: ObjectId[];
    name: string;
    promotion_type_code: LoyaltyPromotionTypeCode;
    psp_ids?: ObjectId[];
    apply_for_customer_code: LoyaltyApplyCustomerCode;
    customer_ids?: ObjectId[];
    customer_group_ids?: ObjectId[];
    apply_for_item_code: LoyaltyApplyItemCode;
    items?: ILoyaltyPromotionItemRule[];
    item_categories?: ILoyaltyPromotionItemCategoryRule[];
    min_quantity?: number;
    discount_percentage?: number;
    discount_amount?: number;
    start_date?: Date;
    end_date?: Date;
    status_code?: LoyaltyPromotionStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ILoyaltyPromotionResult extends Partial<ILoyaltyPromotionDocument> {
}
export interface ILoyaltyPromotionSpec<T> extends Partial<Record<keyof ILoyaltyPromotionDocument, T>> {
}
export interface ILoyaltyPromotionInfo extends Omit<ILoyaltyPromotionDocument, BaseExtractFields> {
}
export interface ILoyaltyPromotionUpdateDocument extends ILoyaltyPromotionResult {
}
export interface ILoyaltyPromotionFilter extends ILoyaltyPromotionResult {
}
export interface ILoyaltyPromotionProjection extends ILoyaltyPromotionSpec<Projection> {
}
export interface ILoyaltyPromotionSort extends ILoyaltyPromotionSpec<Sort> {
}
