import { ObjectId } from 'mongodb';
import { NotificationTypeCode, Projection, Sort, StatusCode, TelegramTypeCode } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IFirebaseConfig {
    firebase_api_url: string;
    firebase_client_email: string;
    firebase_project_id: string;
    firebase_private_key: string;
}
export interface ITelegramGroupChanelConfig {
    _id: ObjectId;
    type: TelegramTypeCode;
    chat_id: string;
    name: string;
}
export interface ITelegramConfig {
    telegram_bot_token: string;
    telegram?: ITelegramGroupChanelConfig[];
}
export interface IMailServerConfig {
    mail_host: string;
    mail_port: string;
    mail_from_address: string;
    mail_from_name: string;
}
export interface INotificationAppConfigDocument {
    _id?: ObjectId;
    app_id: string;
    type_code: NotificationTypeCode;
    config: IFirebaseConfig | ITelegramConfig | IMailServerConfig;
    status_code: StatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by?: ObjectId;
}
export interface INotificationAppConfigResult extends Partial<INotificationAppConfigDocument> {
}
export interface INotificationAppConfigSpec<T> extends Partial<Record<keyof INotificationAppConfigDocument, T>> {
}
export interface INotificationAppConfigInfo extends Omit<INotificationAppConfigDocument, BaseExtractFields> {
}
export interface INotificationAppConfigUpdateDocument extends INotificationAppConfigResult {
}
export interface INotificationAppConfigFilter extends INotificationAppConfigResult {
}
export interface INotificationAppConfigProjection extends INotificationAppConfigSpec<Projection> {
}
export interface INotificationAppConfigSort extends INotificationAppConfigSpec<Sort> {
}
