import { ObjectId } from 'mongodb';
import { POSShiftCashLogType, POSShiftStatusCode, Projection, Sort } from '../../enum';
export interface IShiftCashLog {
    type: POSShiftCashLogType;
    amount: number;
    cash_by_id: ObjectId;
    cash_by_name: string;
    cashed_at: Date;
    notes?: string;
}
export interface IPOSShiftDocument {
    _id?: ObjectId;
    app_id: string;
    branch_id: ObjectId;
    code: string;
    sales_channel_code: string;
    opening_amount: number;
    closed_amount: number;
    total_discount_amount: number;
    total_sales_amount: number;
    total_refund_amount: number;
    cash_logs?: IShiftCashLog[];
    started_at: Date;
    closed_at?: Date;
    status_code: POSShiftStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by?: ObjectId;
}
export interface IPOSShiftResult extends Partial<IPOSShiftDocument> {
}
export interface IPOSShiftSpec<T> extends Partial<Record<keyof IPOSShiftDocument, T>> {
}
export interface IPOSShiftInfo extends Pick<IPOSShiftDocument, 'app_id' | 'branch_id' | 'code' | 'sales_channel_code' | 'opening_amount' | 'started_at' | 'created_by'> {
}
export interface IPOSShiftUpdateDocument extends IPOSShiftResult {
}
export interface IPOSShiftFilter extends IPOSShiftResult {
}
export interface IPOSShiftProjection extends IPOSShiftSpec<Projection> {
}
export interface IPOSShiftSort extends IPOSShiftSpec<Sort> {
}
