import { ObjectId } from 'mongodb';
import { ReservationStatusCode, Projection, Sort, ReservationChannelCode } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IReservationFloor {
    floor_plan_id: ObjectId;
    table_id: ObjectId;
}
export interface IReservationDocument {
    _id?: ObjectId;
    app_id: string;
    branch_id: ObjectId;
    customer_id: ObjectId;
    reservation_channel_code: ReservationChannelCode;
    reservation_date: Date;
    start_time: Date;
    end_time: Date;
    floors: IReservationFloor[];
    reason?: string;
    notes?: string;
    status_code: ReservationStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IReservationResult extends Partial<IReservationDocument> {
}
export interface IReservationSpec<T> extends Partial<Record<keyof IReservationDocument, T>> {
}
export interface IReservationInfo extends Omit<IReservationDocument, BaseExtractFields | 'reservation_date'> {
    reservation_date: string;
}
export interface IReservationUpdateDocument extends IReservationResult {
}
export interface IReservationFilter extends IReservationResult {
}
export interface IReservationProjection extends IReservationSpec<Projection> {
}
export interface IReservationSort extends IReservationSpec<Sort> {
}
