import { ObjectId } from 'mongodb';
import { Projection, PurchaseDocumentTypeCode, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IRefPaymentJournals {
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    document_date: string | Date;
    payment_method_id: ObjectId;
    payment_method_name: string;
    amount: number;
}
export interface IAppliedPaymentSource {
    document_type_code: PurchaseDocumentTypeCode;
    document_no: string;
    source_document_date: Date;
    payment_date: Date;
    source_amount: number;
    source_paid_amount: number;
    source_discount_amount: number;
}
export interface IPaymentDocument {
    _id?: ObjectId;
    payment_no: string;
    app_id: string;
    branch_id: ObjectId;
    type_code: PurchaseDocumentTypeCode;
    document_date: Date;
    posting_date: Date;
    vendor_id: ObjectId;
    payment_method_id: ObjectId;
    bank_account_id?: ObjectId;
    external_document_no?: string;
    currency_code: string;
    exchange_rate: number;
    total_discount_amount: number;
    amount: number;
    remaining_amount: number;
    applied_payment_source: IAppliedPaymentSource[];
    is_deposit: boolean;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPaymentResult extends Partial<IPaymentDocument> {
}
export interface IPaymentSpec<T> extends Partial<Record<keyof IPaymentDocument, T>> {
}
export interface IPaymentInfo extends Omit<IPaymentDocument, BaseExtractFields> {
}
export interface IPaymentUpdateDocument extends IPaymentResult {
}
export interface IPaymentFilter extends IPaymentResult {
}
export interface IPaymentProjection extends IPaymentSpec<Projection> {
}
export interface IPaymentSort extends IPaymentSpec<Sort> {
}
