import { ObjectId } from 'mongodb';
import { DiscountLevelType, Projection, PurchaseDocumentTypeCode, RefundStatusCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { IPurchaseLineDocument } from './purchase.interface';
import { BaseExtractFields } from '../base.interface';
import { IRefPaymentJournals } from './payment.interface';
export interface IAppliedPurchaseInvoices {
    document_no: string;
    document_date: string | Date;
    applied_date: string | Date;
    applied_amount: number;
}
export interface IPurchaseCreditMemoHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
    order_type_code: PurchaseDocumentTypeCode;
    app_id: string;
    branch_id: ObjectId;
    registered_tax_no?: string;
    external_document_no?: string;
    document_date: Date;
    warehouse_id: ObjectId;
    vendor_id: ObjectId;
    payment_term_id?: ObjectId;
    payment_term_disc_per?: number;
    payment_term_num_of_day?: number;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    total_remaining_amount: number;
    total_payment?: number;
    ref_payment_journals?: IRefPaymentJournals[];
    total_applied_inv_amount?: number;
    applied_invoices?: IAppliedPurchaseInvoices[];
    status_code: RefundStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPurchaseCreditMemoHeaderResult extends Partial<IPurchaseCreditMemoHeaderDocument> {
}
export interface IPurchaseCreditMemoHeaderSpec<T> extends Partial<Record<keyof IPurchaseCreditMemoHeaderDocument, T>> {
}
export interface IPurchaseCreditMemoHeaderInfo extends Omit<IPurchaseCreditMemoHeaderDocument, BaseExtractFields> {
}
export interface IPurchaseCreditMemoHeaderUpdateDocument extends IPurchaseCreditMemoHeaderResult {
}
export interface IPurchaseCreditMemoHeaderFilter extends IPurchaseCreditMemoHeaderResult {
}
export interface IPurchaseCreditMemoHeaderProjection extends IPurchaseCreditMemoHeaderSpec<Projection> {
}
export interface IPurchaseCreditMemoHeaderSort extends IPurchaseCreditMemoHeaderSpec<Sort> {
}
export interface IPurchaseCreditMemoLineDocument extends Omit<IPurchaseLineDocument, 'quantity_to_invoice' | 'quantity_to_ship' | 'quantity_shipped' | 'quantity_to_receive' | 'quantity_received' | 'quantity_invoiced'> {
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    app_id: string;
    branch_id: ObjectId;
    document_date: Date;
    remaining_amount: number;
    applied_refund_amount?: number;
    applied_invoice_amount?: number;
}
export interface IPurchaseCreditMemoLineResult extends Partial<IPurchaseCreditMemoLineDocument> {
}
export interface IPurchaseCreditMemoLineSpec<T> extends Partial<Record<keyof IPurchaseCreditMemoLineDocument, T>> {
}
export interface IPurchaseCreditMemoLineInfo extends Omit<IPurchaseCreditMemoLineDocument, BaseExtractFields> {
}
export interface IPurchaseCreditMemoLineUpdateDocument extends IPurchaseCreditMemoLineResult {
}
export interface IPurchaseCreditMemoLineFilter extends IPurchaseCreditMemoLineResult {
}
export interface IPurchaseCreditMemoLineProjection extends IPurchaseCreditMemoLineSpec<Projection> {
}
export interface IPurchaseCreditMemoLineSort extends IPurchaseCreditMemoLineSpec<Sort> {
}
