import { ObjectId } from 'mongodb';
import { PurchaseDocumentStatusCode, PurchaseDocumentTypeCode, Projection, Sort, DiscountLevelType, VATCalculationType, VATType, ApprovalStatusCode, TaxType, TaxTypeCode, ItemTypeCode } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IPurchaseHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    ref_document_id?: ObjectId;
    ref_document_no?: string;
    ref_document_type_code?: PurchaseDocumentTypeCode;
    external_document_no?: string;
    order_date: Date;
    document_due_date: Date;
    expected_delivery_date?: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    vendor_id: ObjectId;
    shipping_address?: string;
    shipping_city?: string;
    shipping_state?: string;
    shipping_zip_code?: string;
    shipping_phone?: string;
    payment_term_id: ObjectId;
    payment_term_name: string;
    payment_term_dis_per: number;
    payment_term_num_of_day: number;
    shipment_agent_id?: ObjectId;
    shipment_agent_name?: string;
    external_ref_shipment_no?: string;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    status_code: PurchaseDocumentStatusCode;
    approval_status_code?: ApprovalStatusCode;
    received_status_code: PurchaseDocumentStatusCode;
    invoiced_status_code: PurchaseDocumentStatusCode;
    shipped_status_code: PurchaseDocumentStatusCode;
    credit_memo_status_code: PurchaseDocumentStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPurchaseHeaderResult extends Partial<IPurchaseHeaderDocument> {
}
export interface IPurchaseHeaderSpec<T> extends Partial<Record<keyof IPurchaseHeaderDocument, T>> {
}
export interface IPurchaseHeaderInfo extends Omit<IPurchaseHeaderDocument, '_id' | 'created_at' | 'updated_at'> {
    vendor_has_transaction?: boolean;
    manufacturer_has_transaction?: boolean;
}
export interface IPurchaseHeaderUpdateDocument extends IPurchaseHeaderResult {
}
export interface IPurchaseHeaderFilter extends IPurchaseHeaderResult {
}
export interface IPurchaseHeaderProjection extends IPurchaseHeaderSpec<Projection> {
}
export interface IPurchaseHeaderSort extends IPurchaseHeaderSpec<Sort> {
}
export interface IPurchaseLineDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    app_id: string;
    branch_id: ObjectId;
    order_date: Date;
    vendor_id: ObjectId;
    item_type_code: ItemTypeCode;
    item_id: ObjectId;
    item_sku: string;
    variant_id?: ObjectId;
    category_id: ObjectId;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    base_unit_id: ObjectId;
    base_unit_name: string;
    base_unit_factor: number;
    quantity: number;
    base_quantity: number;
    currency_code: string;
    exchange_rate: number;
    cost_price: number;
    base_cost_price: number;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    vat_calculation_type: VATCalculationType;
    vat_percentage: number;
    vat_amount: number;
    amount: number;
    amount_exclude_vat: number;
    quantity_to_receive?: number;
    quantity_received?: number;
    quantity_to_invoice?: number;
    quantity_invoiced?: number;
    quantity_to_ship?: number;
    quantity_shipped?: number;
    quantity_to_credit_memo?: number;
    quantity_credit_memo?: number;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPurchaseLineResult extends Partial<IPurchaseLineDocument> {
}
export interface IPurchaseLineSpec<T> extends Partial<Record<keyof IPurchaseLineDocument, T>> {
}
export interface IPurchaseLineInfo extends Omit<IPurchaseLineDocument, BaseExtractFields> {
}
export interface IPurchaseLineUpdateDocument extends IPurchaseLineResult {
}
export interface IPurchaseLineFilter extends IPurchaseLineResult {
}
export interface IPurchaseLineProjection extends IPurchaseLineSpec<Projection> {
}
export interface IPurchaseLineSort extends IPurchaseLineSpec<Sort> {
}
