import { ObjectId } from 'mongodb';
import { DiscountLevelType, PaymentStatusCode, Projection, PurchaseDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { IPurchaseLineDocument } from './purchase.interface';
import { IRefPaymentJournals } from './payment.interface';
import { BaseExtractFields } from '../base.interface';
export interface IAppliedPurchaseCreditMemos {
    document_no: string;
    document_date: string | Date;
    applied_date: string | Date;
    applied_amount: number;
}
export interface IPurchaseInvoiceHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    registered_tax_no?: string;
    external_document_no?: string;
    document_date: Date;
    document_due_date: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    vendor_id: ObjectId;
    payment_term_id: ObjectId;
    payment_term_name: string;
    payment_term_dis_per: number;
    payment_term_num_of_day: number;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    total_remaining_amount: number;
    total_payment?: number;
    ref_payment_journals?: IRefPaymentJournals[];
    total_applied_cr_amount?: number;
    applied_credit_memos?: IAppliedPurchaseCreditMemos[];
    status_code: PaymentStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPurchaseInvoiceHeaderResult extends Partial<IPurchaseInvoiceHeaderDocument> {
}
export interface IPurchaseInvoiceHeaderSpec<T> extends Partial<Record<keyof IPurchaseInvoiceHeaderDocument, T>> {
}
export interface IPurchaseInvoiceHeaderInfo extends Omit<IPurchaseInvoiceHeaderDocument, BaseExtractFields> {
}
export interface IPurchaseInvoiceHeaderUpdateDocument extends IPurchaseInvoiceHeaderResult {
}
export interface IPurchaseInvoiceHeaderFilter extends IPurchaseInvoiceHeaderResult {
}
export interface IPurchaseInvoiceHeaderProjection extends IPurchaseInvoiceHeaderSpec<Projection> {
}
export interface IPurchaseInvoiceHeaderSort extends IPurchaseInvoiceHeaderSpec<Sort> {
}
export interface IPurchaseInvoiceLineDocument extends Omit<IPurchaseLineDocument, 'quantity_to_invoice' | 'quantity_to_ship' | 'quantity_shipped' | 'quantity_to_receive' | 'quantity_received' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    remaining_amount: number;
    applied_payment_amount?: number;
    applied_credit_memo_amount?: number;
}
export interface IPurchaseInvoiceLineResult extends Partial<IPurchaseInvoiceLineDocument> {
}
export interface IPurchaseInvoiceLineSpec<T> extends Partial<Record<keyof IPurchaseInvoiceLineDocument, T>> {
}
export interface IPurchaseInvoiceLineInfo extends Omit<IPurchaseInvoiceLineDocument, BaseExtractFields> {
}
export interface IPurchaseInvoiceLineUpdateDocument extends IPurchaseInvoiceLineResult {
}
export interface IPurchaseInvoiceLineFilter extends IPurchaseInvoiceLineResult {
}
export interface IPurchaseInvoiceLineProjection extends IPurchaseInvoiceLineSpec<Projection> {
}
export interface IPurchaseInvoiceLineSort extends IPurchaseInvoiceLineSpec<Sort> {
}
