import { ObjectId } from 'mongodb';
import { DiscountLevelType, Projection, PurchaseDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { IPurchaseLineDocument } from './purchase.interface';
export interface IPurchaseReceiptHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    app_id: string;
    branch_id: ObjectId;
    external_document_no?: string;
    document_date: Date;
    warehouse_id: ObjectId;
    vendor_id: ObjectId;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPurchaseReceiptHeaderResult extends Partial<IPurchaseReceiptHeaderDocument> {
}
export interface IPurchaseReceiptHeaderSpec<T> extends Partial<Record<keyof IPurchaseReceiptHeaderDocument, T>> {
}
export interface IPurchaseReceiptHeaderInfo extends Omit<IPurchaseReceiptHeaderDocument, BaseExtractFields> {
}
export interface IPurchaseReceiptHeaderUpdateDocument extends IPurchaseReceiptHeaderResult {
}
export interface IPurchaseReceiptHeaderFilter extends IPurchaseReceiptHeaderResult {
}
export interface IPurchaseReceiptHeaderProjection extends IPurchaseReceiptHeaderSpec<Projection> {
}
export interface IPurchaseReceiptHeaderSort extends IPurchaseReceiptHeaderSpec<Sort> {
}
export interface IPurchaseReceiptLineDocument extends Omit<IPurchaseLineDocument, 'quantity_to_receive' | 'quantity_to_ship' | 'quantity_shipped' | 'quantity_to_invoice' | 'quantity_invoiced' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    warehouse_id: ObjectId;
}
export interface IPurchaseReceiptLineResult extends Partial<IPurchaseReceiptLineDocument> {
}
export interface IPurchaseReceiptLineSpec<T> extends Partial<Record<keyof IPurchaseReceiptLineDocument, T>> {
}
export interface IPurchaseReceiptLineInfo extends Omit<IPurchaseReceiptLineDocument, BaseExtractFields> {
}
export interface IPurchaseReceiptLineUpdateDocument extends IPurchaseReceiptLineResult {
}
export interface IPurchaseReceiptLineFilter extends IPurchaseReceiptLineResult {
}
export interface IPurchaseReceiptLineProjection extends IPurchaseReceiptLineSpec<Projection> {
}
export interface IPurchaseReceiptLineSort extends IPurchaseReceiptLineSpec<Sort> {
}
