import { ObjectId } from 'mongodb';
import { DiscountLevelType, Projection, PurchaseDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { IPurchaseLineDocument } from './purchase.interface';
export interface IPurchaseShipmentHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: PurchaseDocumentTypeCode;
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    app_id: string;
    branch_id: ObjectId;
    external_document_no?: string;
    document_date: Date;
    warehouse_id: ObjectId;
    vendor_id: ObjectId;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IPurchaseShipmentHeaderResult extends Partial<IPurchaseShipmentHeaderDocument> {
}
export interface IPurchaseShipmentHeaderSpec<T> extends Partial<Record<keyof IPurchaseShipmentHeaderDocument, T>> {
}
export interface IPurchaseShipmentHeaderInfo extends Omit<IPurchaseShipmentHeaderDocument, BaseExtractFields> {
}
export interface IPurchaseShipmentHeaderUpdateDocument extends IPurchaseShipmentHeaderResult {
}
export interface IPurchaseShipmentHeaderFilter extends IPurchaseShipmentHeaderResult {
}
export interface IPurchaseShipmentHeaderProjection extends IPurchaseShipmentHeaderSpec<Projection> {
}
export interface IPurchaseShipmentHeaderSort extends IPurchaseShipmentHeaderSpec<Sort> {
}
export interface IPurchaseShipmentLineDocument extends Omit<IPurchaseLineDocument, 'quantity_to_receive' | 'quantity_to_ship' | 'quantity_received' | 'quantity_to_invoice' | 'quantity_invoiced' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    warehouse_id: ObjectId;
}
export interface IPurchaseShipmentLineResult extends Partial<IPurchaseShipmentLineDocument> {
}
export interface IPurchaseShipmentLineSpec<T> extends Partial<Record<keyof IPurchaseShipmentLineDocument, T>> {
}
export interface IPurchaseShipmentLineInfo extends Omit<IPurchaseShipmentLineDocument, BaseExtractFields> {
}
export interface IPurchaseShipmentLineUpdateDocument extends IPurchaseShipmentLineResult {
}
export interface IPurchaseShipmentLineFilter extends IPurchaseShipmentLineResult {
}
export interface IPurchaseShipmentLineProjection extends IPurchaseShipmentLineSpec<Projection> {
}
export interface IPurchaseShipmentLineSort extends IPurchaseShipmentLineSpec<Sort> {
}
