import { ObjectId } from 'mongodb';
import { Projection, SalesDocumentTypeCode, Sort } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface IRefCashReceiptJournal {
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    document_date: string | Date;
    payment_method_id: ObjectId;
    payment_method_name: string;
    amount: number;
}
export interface IAppliedCashReceiptSource {
    document_type_code: SalesDocumentTypeCode;
    document_no: string;
    source_document_date: Date;
    cash_receipt_date: Date;
    source_amount: number;
    source_paid_amount: number;
    source_discount_amount: number;
}
export interface ICashReceiptDocument {
    _id?: ObjectId;
    document_no: string;
    app_id: string;
    branch_id: ObjectId;
    type_code: SalesDocumentTypeCode;
    document_date: Date;
    posting_date: Date;
    customer_id: ObjectId;
    payment_method_id: ObjectId;
    bank_account_id?: ObjectId;
    external_document_no?: string;
    currency_code: string;
    exchange_rate: number;
    total_discount_amount: number;
    amount: number;
    remaining_amount: number;
    applied_cash_receipt_source: IAppliedCashReceiptSource[];
    is_deposit: boolean;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ICashReceiptResult extends Partial<ICashReceiptDocument> {
}
export interface ICashReceiptSpec<T> extends Partial<Record<keyof ICashReceiptDocument, T>> {
}
export interface ICashReceiptInfo extends Omit<ICashReceiptDocument, BaseExtractFields> {
}
export interface ICashReceiptUpdateDocument extends ICashReceiptResult {
}
export interface ICashReceiptFilter extends ICashReceiptResult {
}
export interface ICashReceiptProjection extends ICashReceiptSpec<Projection> {
}
export interface ICashReceiptSort extends ICashReceiptSpec<Sort> {
}
