import { ObjectId } from 'mongodb';
import { CashReceiptRefundStatusCode, DiscountLevelType, Projection, SalesDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { IRefCashReceiptJournal } from './cash.receipt.interface';
import { ISalesLineDocument } from './sales.interface';
export interface IAppliedSalesInvoices {
    document_no: string;
    document_date: string | Date;
    applied_date: string | Date;
    applied_amount: number;
}
export interface ISalesCreditMemoHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
    order_type_code: SalesDocumentTypeCode;
    app_id: string;
    branch_id: ObjectId;
    registered_tax_no?: string;
    external_document_no?: string;
    document_date: Date;
    warehouse_id: ObjectId;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    salesperson_id?: ObjectId;
    sales_channel_code: string;
    payment_term_id: ObjectId;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    total_remaining_amount: number;
    total_cash_receipt?: number;
    ref_cash_receipt_journals?: IRefCashReceiptJournal[];
    total_applied_inv_amount?: number;
    applied_invoices?: IAppliedSalesInvoices[];
    status_code: CashReceiptRefundStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesCreditMemoHeaderResult extends Partial<ISalesCreditMemoHeaderDocument> {
}
export interface ISalesCreditMemoHeaderSpec<T> extends Partial<Record<keyof ISalesCreditMemoHeaderDocument, T>> {
}
export interface ISalesCreditMemoHeaderInfo extends Omit<ISalesCreditMemoHeaderDocument, '_id' | 'created_at' | 'updated_at'> {
}
export interface ISalesCreditMemoHeaderUpdateDocument extends ISalesCreditMemoHeaderResult {
}
export interface ISalesCreditMemoHeaderFilter extends ISalesCreditMemoHeaderResult {
}
export interface ISalesCreditMemoHeaderProjection extends ISalesCreditMemoHeaderSpec<Projection> {
}
export interface ISalesCreditMemoHeaderSort extends ISalesCreditMemoHeaderSpec<Sort> {
}
export interface ISalesCreditMemoLineDocument extends Omit<ISalesLineDocument, 'quantity_to_package' | 'quantity_packaged' | 'quantity_to_invoice' | 'quantity_to_ship' | 'quantity_shipped' | 'quantity_to_receive' | 'quantity_received' | 'quantity_invoiced'> {
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_type_code: SalesDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    remaining_amount: number;
    applied_refund_amount?: number;
    applied_invoice_amount?: number;
    sales_channel_code: string;
}
export interface ISalesCreditMemoLineResult extends Partial<ISalesCreditMemoLineDocument> {
}
export interface ISalesCreditMemoLineSpec<T> extends Partial<Record<keyof ISalesCreditMemoLineDocument, T>> {
}
export interface ISalesCreditMemoLineInfo extends Omit<ISalesCreditMemoLineDocument, BaseExtractFields> {
}
export interface ISalesCreditMemoLineUpdateDocument extends ISalesCreditMemoLineResult {
}
export interface ISalesCreditMemoLineFilter extends ISalesCreditMemoLineResult {
}
export interface ISalesCreditMemoLineProjection extends ISalesCreditMemoLineSpec<Projection> {
}
export interface ISalesCreditMemoLineSort extends ISalesCreditMemoLineSpec<Sort> {
}
