import { ObjectId } from 'mongodb';
import { DiscountLevelType, ItemTypeCode, Projection, SalesDocumentStatusCode, SalesDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface ISalesHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    ref_document_id?: ObjectId;
    ref_document_no?: string;
    ref_document_type_code?: SalesDocumentTypeCode;
    registered_tax_no?: string;
    external_document_no?: string;
    order_date: Date;
    document_due_date: Date;
    expected_delivery_date?: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    salesperson_id?: ObjectId;
    shipping_address?: string;
    shipping_city?: string;
    shipping_state?: string;
    shipping_zip_code?: string;
    shipping_phone?: string;
    billing_address?: string;
    billing_city?: string;
    billing_state?: string;
    billing_zip_code?: string;
    billing_phone?: string;
    payment_term_id: ObjectId;
    shipment_agent_id?: ObjectId;
    external_ref_shipment_no?: string;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    status_code: SalesDocumentStatusCode;
    package_status_code: SalesDocumentStatusCode;
    shipped_status_code: SalesDocumentStatusCode;
    invoiced_status_code: SalesDocumentStatusCode;
    received_status_code: SalesDocumentStatusCode;
    credit_memo_status_code: SalesDocumentStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesHeaderResult extends Partial<ISalesHeaderDocument> {
}
export interface ISalesHeaderSpec<T> extends Partial<Record<keyof ISalesHeaderDocument, T>> {
}
export interface ISalesHeaderInfo extends Omit<ISalesHeaderDocument, BaseExtractFields> {
    vendor_has_transaction?: boolean;
}
export interface ISalesHeaderUpdateDocument extends ISalesHeaderResult {
}
export interface ISalesHeaderFilter extends ISalesHeaderResult {
}
export interface ISalesHeaderProjection extends ISalesHeaderSpec<Projection> {
}
export interface ISalesHeaderSort extends ISalesHeaderSpec<Sort> {
}
export interface IKDSOrderItemModifier {
    _id: ObjectId;
    item_modifier_id: ObjectId;
    selling_price: number;
}
export interface IKDSOrder {
    _id: ObjectId;
    item_id: ObjectId;
    quantity: number;
    item_modifiers: IKDSOrderItemModifier[];
    notes?: string;
}
export interface ISalesLineAttribute {
    kitchen_orders: IKDSOrder[];
}
export interface ISalesLineDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    app_id: string;
    branch_id: ObjectId;
    order_date: Date;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    item_type_code: ItemTypeCode;
    item_id: ObjectId;
    item_sku: string;
    variant_id?: ObjectId;
    category_id: ObjectId;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    base_unit_id: ObjectId;
    base_unit_name: string;
    base_unit_factor: number;
    quantity: number;
    base_quantity: number;
    currency_code: string;
    exchange_rate: number;
    unit_price: number;
    base_unit_price: number;
    discount_percentage?: number;
    discount_amount?: number;
    total_discount_amount?: number;
    vat_calculation_type: VATCalculationType;
    vat_percentage: number;
    vat_amount: number;
    amount: number;
    amount_exclude_vat: number;
    quantity_to_package?: number;
    quantity_packaged?: number;
    quantity_to_ship?: number;
    quantity_shipped?: number;
    quantity_to_invoice?: number;
    quantity_invoiced?: number;
    quantity_to_receive?: number;
    quantity_received?: number;
    quantity_to_credit_memo?: number;
    quantity_credit_memo?: number;
    attributes?: ISalesLineAttribute;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesLineResult extends Partial<ISalesLineDocument> {
}
export interface ISalesLineSpec<T> extends Partial<Record<keyof ISalesLineDocument, T>> {
}
export interface ISalesLineInfo extends Omit<ISalesLineDocument, BaseExtractFields> {
}
export interface ISalesLineUpdateDocument extends ISalesLineResult {
}
export interface ISalesLineFilter extends ISalesLineResult {
}
export interface ISalesLineProjection extends ISalesLineSpec<Projection> {
}
export interface ISalesLineSort extends ISalesLineSpec<Sort> {
}
