import { ObjectId } from 'mongodb';
import { CashReceiptStatusCode, DiscountLevelType, Projection, SalesDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { IRefCashReceiptJournal } from './cash.receipt.interface';
import { ISalesLineDocument } from './sales.interface';
export interface IAppliedSalesCreditMemos {
    document_no: string;
    document_date: string | Date;
    applied_date: string | Date;
    applied_amount: number;
}
export interface ISalesInvoiceHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_type_code: SalesDocumentTypeCode;
    order_date: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    registered_tax_no?: string;
    external_document_no?: string;
    document_date: Date;
    document_due_date: Date;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    salesperson_id?: ObjectId;
    sales_channel_code: string;
    billing_address?: string;
    billing_city?: string;
    billing_state?: string;
    billing_zip_code?: string;
    billing_phone?: string;
    payment_term_id: ObjectId;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    total_remaining_amount: number;
    total_cash_receipt?: number;
    ref_cash_receipt_journals?: IRefCashReceiptJournal[];
    total_applied_cr_amount?: number;
    applied_credit_memos?: IAppliedSalesCreditMemos[];
    status_code: CashReceiptStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesInvoiceHeaderResult extends Partial<ISalesInvoiceHeaderDocument> {
}
export interface ISalesInvoiceHeaderSpec<T> extends Partial<Record<keyof ISalesInvoiceHeaderDocument, T>> {
}
export interface ISalesInvoiceHeaderInfo extends Omit<ISalesInvoiceHeaderDocument, BaseExtractFields> {
}
export interface ISalesInvoiceHeaderUpdateDocument extends ISalesInvoiceHeaderResult {
}
export interface ISalesInvoiceHeaderFilter extends ISalesInvoiceHeaderResult {
}
export interface ISalesInvoiceHeaderProjection extends ISalesInvoiceHeaderSpec<Projection> {
}
export interface ISalesInvoiceHeaderSort extends ISalesInvoiceHeaderSpec<Sort> {
}
export interface ISalesInvoiceLineDocument extends Omit<ISalesLineDocument, 'quantity_to_package' | 'quantity_packaged' | 'quantity_to_invoice' | 'quantity_to_ship' | 'quantity_shipped' | 'quantity_to_receive' | 'quantity_received' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    tax_invoice_no?: string;
    order_id: ObjectId;
    order_no: string;
    order_type_code: SalesDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    remaining_amount: number;
    sales_channel_code: string;
}
export interface ISalesInvoiceLineResult extends Partial<ISalesInvoiceLineDocument> {
}
export interface ISalesInvoiceLineSpec<T> extends Partial<Record<keyof ISalesInvoiceLineDocument, T>> {
}
export interface ISalesInvoiceLineInfo extends Omit<ISalesInvoiceLineDocument, BaseExtractFields> {
}
export interface ISalesInvoiceLineUpdateDocument extends ISalesInvoiceLineResult {
}
export interface ISalesInvoiceLineFilter extends ISalesInvoiceLineResult {
}
export interface ISalesInvoiceLineProjection extends ISalesInvoiceLineSpec<Projection> {
}
export interface ISalesInvoiceLineSort extends ISalesInvoiceLineSpec<Sort> {
}
