import { ObjectId } from 'mongodb';
import { DiscountLevelType, Projection, PurchaseDocumentTypeCode, SalesDocumentTypeCode, SalesShipmentStatusCode, Sort, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { ISalesLineDocument } from './sales.interface';
export interface ISalesPackageHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    order_id: ObjectId;
    order_no: string;
    order_date: Date;
    order_type_code?: SalesDocumentTypeCode;
    shipment_id?: ObjectId;
    shipment_no?: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    external_document_no?: string;
    document_date: Date;
    salesperson_id?: ObjectId;
    salesperson_name?: string;
    discount_level_type?: DiscountLevelType;
    discount_amount: number;
    discount_percentage: number;
    total_discount_amount: number;
    tax_type_code?: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    status_code: SalesShipmentStatusCode;
    ship_status_code: SalesShipmentStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesPackageHeaderResult extends Partial<ISalesPackageHeaderDocument> {
}
export interface ISalesPackageHeaderSpec<T> extends Partial<Record<keyof ISalesPackageHeaderDocument, T>> {
}
export interface ISalesPackageHeaderInfo extends Omit<ISalesPackageHeaderDocument, BaseExtractFields> {
}
export interface ISalesPackageHeaderUpdateDocument extends ISalesPackageHeaderResult {
}
export interface ISalesPackageHeaderFilter extends ISalesPackageHeaderResult {
}
export interface ISalesPackageHeaderProjection extends ISalesPackageHeaderSpec<Projection> {
}
export interface ISalesPackageHeaderSort extends ISalesPackageHeaderSpec<Sort> {
}
export interface ISalesPackageLineDocument extends Omit<ISalesLineDocument, 'quantity_to_package' | 'quantity_packaged' | 'quantity_to_receive' | 'quantity_received' | 'quantity_to_invoice' | 'quantity_invoiced' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    order_id: ObjectId;
    order_no: string;
    order_type_code: PurchaseDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    warehouse_id: ObjectId;
}
export interface ISalesPackageLineResult extends Partial<ISalesPackageLineDocument> {
}
export interface ISalesPackageLineSpec<T> extends Partial<Record<keyof ISalesPackageLineDocument, T>> {
}
export interface ISalesPackageLineInfo extends Omit<ISalesPackageLineDocument, BaseExtractFields> {
}
export interface ISalesPackageLineUpdateDocument extends ISalesPackageLineResult {
}
export interface ISalesPackageLineFilter extends ISalesPackageLineResult {
}
export interface ISalesPackageLineProjection extends ISalesPackageLineSpec<Projection> {
}
export interface ISalesPackageLineSort extends ISalesPackageLineSpec<Sort> {
}
