import { ObjectId } from 'mongodb';
import { DiscountLevelType, Projection, SalesDocumentTypeCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { ISalesLineDocument } from './sales.interface';
export interface ISalesReceiptHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    order_id: ObjectId;
    order_no: string;
    order_type_code: SalesDocumentTypeCode;
    order_date: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    external_document_no?: string;
    document_date: Date;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    salesperson_id?: ObjectId;
    sales_channel_code?: string;
    currency_code: string;
    exchange_rate: number;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    tax_type: TaxType;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesReceiptHeaderResult extends Partial<ISalesReceiptHeaderDocument> {
}
export interface ISalesReceiptHeaderSpec<T> extends Partial<Record<keyof ISalesReceiptHeaderDocument, T>> {
}
export interface ISalesReceiptHeaderInfo extends Omit<ISalesReceiptHeaderDocument, BaseExtractFields> {
}
export interface ISalesReceiptHeaderUpdateDocument extends ISalesReceiptHeaderResult {
}
export interface ISalesReceiptHeaderFilter extends ISalesReceiptHeaderResult {
}
export interface ISalesReceiptHeaderProjection extends ISalesReceiptHeaderSpec<Projection> {
}
export interface ISalesReceiptHeaderSort extends ISalesReceiptHeaderSpec<Sort> {
}
export interface ISalesReceiptLineDocument extends Omit<ISalesLineDocument, 'quantity_to_package' | 'quantity_packaged' | 'quantity_to_receive' | 'quantity_to_ship' | 'quantity_shipped' | 'quantity_to_invoice' | 'quantity_invoiced' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    order_id: ObjectId;
    order_no: string;
    order_type_code: SalesDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    warehouse_id: ObjectId;
    sales_channel_code?: string;
}
export interface ISalesReceiptLineResult extends Partial<ISalesReceiptLineDocument> {
}
export interface ISalesReceiptLineSpec<T> extends Partial<Record<keyof ISalesReceiptLineDocument, T>> {
}
export interface ISalesReceiptLineInfo extends Omit<ISalesReceiptLineDocument, BaseExtractFields> {
}
export interface ISalesReceiptLineUpdateDocument extends ISalesReceiptLineResult {
}
export interface ISalesReceiptLineFilter extends ISalesReceiptLineResult {
}
export interface ISalesReceiptLineProjection extends ISalesReceiptLineSpec<Projection> {
}
export interface ISalesReceiptLineSort extends ISalesReceiptLineSpec<Sort> {
}
