import { ObjectId } from 'mongodb';
import { DiscountLevelType, Projection, SalesDocumentTypeCode, SalesShipmentStatusCode, Sort, TaxType, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
import { ISalesLineDocument } from './sales.interface';
export interface ISalesShipmentHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    document_type_code: SalesDocumentTypeCode;
    order_id?: ObjectId;
    order_no?: string;
    order_type_code?: SalesDocumentTypeCode;
    order_date?: Date;
    app_id: string;
    branch_id: ObjectId;
    warehouse_id: ObjectId;
    customer_id?: ObjectId;
    customer_group_id?: ObjectId;
    sales_channel_code?: string;
    external_document_no?: string;
    document_date: Date;
    packages_no?: [string];
    shipment_agent_id?: ObjectId;
    shipping_address?: string;
    shipping_city?: string;
    shipping_state?: string;
    shipping_zip_code?: string;
    shipping_phone?: string;
    tracking_no?: string;
    tracking_url?: string;
    shipping_charges?: number;
    currency_code: string;
    exchange_rate: number;
    discount_level_type?: DiscountLevelType;
    discount_amount?: number;
    discount_percentage: number;
    total_discount_amount: number;
    tax_type?: TaxType;
    tax_type_code?: TaxTypeCode;
    vat_type?: VATType;
    vat_calculation_type?: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    is_from_package: boolean;
    delivered_at?: Date;
    status_code: SalesShipmentStatusCode;
    notes?: string;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISalesShipmentHeaderResult extends Partial<ISalesShipmentHeaderDocument> {
}
export interface ISalesShipmentHeaderSpec<T> extends Partial<Record<keyof ISalesShipmentHeaderDocument, T>> {
}
export interface ISalesShipmentHeaderInfo extends Omit<ISalesShipmentHeaderDocument, BaseExtractFields> {
}
export interface ISalesShipmentHeaderUpdateDocument extends ISalesShipmentHeaderResult {
}
export interface ISalesShipmentHeaderFilter extends ISalesShipmentHeaderResult {
}
export interface ISalesShipmentHeaderProjection extends ISalesShipmentHeaderSpec<Projection> {
}
export interface ISalesShipmentHeaderSort extends ISalesShipmentHeaderSpec<Sort> {
}
export interface ISalesShipmentLineDocument extends Omit<ISalesLineDocument, 'quantity_to_package' | 'quantity_packaged' | 'quantity_to_receive' | 'quantity_to_ship' | 'quantity_received' | 'quantity_to_invoice' | 'quantity_invoiced' | 'quantity_to_credit_memo' | 'quantity_credit_memo'> {
    order_id: ObjectId;
    order_no: string;
    order_type_code: SalesDocumentTypeCode;
    order_date: Date;
    order_line_id: ObjectId;
    branch_id: ObjectId;
    document_date: Date;
    warehouse_id: ObjectId;
    package_no?: string;
    package_line_id?: ObjectId;
    sales_channel_code?: string;
}
export interface ISalesShipmentLineResult extends Partial<ISalesShipmentLineDocument> {
}
export interface ISalesShipmentLineSpec<T> extends Partial<Record<keyof ISalesShipmentLineDocument, T>> {
}
export interface ISalesShipmentLineInfo extends Omit<ISalesShipmentLineDocument, BaseExtractFields> {
}
export interface ISalesShipmentLineUpdateDocument extends ISalesShipmentLineResult {
}
export interface ISalesShipmentLineFilter extends ISalesShipmentLineResult {
}
export interface ISalesShipmentLineProjection extends ISalesShipmentLineSpec<Projection> {
}
export interface ISalesShipmentLineSort extends ISalesShipmentLineSpec<Sort> {
}
