import { ObjectId } from 'mongodb';
import { BillingCycleCode, DiscountLevelType, ItemTypeCode, Projection, Sort, SubscriptionLineStatusCode, SubscriptionStatusCode, TaxTypeCode, VATCalculationType, VATType } from '../../enum';
import { BaseExtractFields } from '../base.interface';
export interface ISubscriptionHeaderDocument {
    _id?: ObjectId;
    document_no: string;
    branch_id: ObjectId;
    customer_id: ObjectId;
    customer_group_id: ObjectId;
    country_code?: string;
    product_id: ObjectId;
    plan_id: ObjectId;
    billing_interval_code: string;
    billing_cycle_code?: BillingCycleCode;
    salesperson_id?: ObjectId;
    initialed_at: Date;
    activated_at: Date;
    started_at: Date;
    expired_at: Date;
    trial_period?: number;
    trial_expired_at?: Date;
    last_billing_at?: Date;
    next_billing_at: Date;
    suspended_at: Date;
    last_upgraded_at?: Date;
    last_downgraded_at?: Date;
    payment_term_id?: ObjectId;
    is_metered_billing?: boolean;
    remaining_billing_cycle: number;
    currency_code: string;
    exchange_rate: number;
    voucher_code?: string;
    discount_level_type: DiscountLevelType;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount: number;
    tax_type_code: TaxTypeCode;
    vat_type: VATType;
    vat_calculation_type: VATCalculationType;
    vat_id: ObjectId;
    vat_name: string;
    vat_percentage: number;
    total_vat_amount: number;
    total_amount: number;
    total_amount_exclude_vat: number;
    customer_notes?: string;
    status_code: SubscriptionStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISubscriptionHeaderResult extends Partial<ISubscriptionHeaderDocument> {
}
export interface ISubscriptionHeaderSpec<T> extends Partial<Record<keyof ISubscriptionHeaderDocument, T>> {
}
export interface ISubscriptionHeaderInfo extends Omit<ISubscriptionHeaderDocument, BaseExtractFields | 'initialed_at' | 'activated_at' | 'started_at' | 'expired_at' | 'trial_expired_at' | 'last_billing_at' | 'next_billing_at' | 'suspended_at' | 'last_upgraded_at' | 'last_downgraded_at'> {
    initialed_at: string;
    activated_at: string;
    started_at: string;
    expired_at: string;
    trial_expired_at: string;
    last_billing_at?: string;
    next_billing_at?: string;
    suspended_at: string;
    last_upgraded_at?: string;
    last_downgraded_at?: string;
}
export interface ISubscriptionHeaderUpdateDocument extends ISubscriptionHeaderResult {
}
export interface ISubscriptionHeaderFilter extends ISubscriptionHeaderResult {
}
export interface ISubscriptionHeaderProjection extends ISubscriptionHeaderSpec<Projection> {
}
export interface ISubscriptionHeaderSort extends ISubscriptionHeaderSpec<Sort> {
}
export interface ISubscriptionLineDocument {
    _id?: ObjectId;
    document_no: string;
    branch_id: ObjectId;
    customer_id: ObjectId;
    customer_group_id?: ObjectId;
    item_type_code: ItemTypeCode;
    product_id: ObjectId;
    plan_id: ObjectId;
    addon_id: ObjectId;
    billing_cycle_code?: BillingCycleCode;
    category_id: ObjectId;
    unit_id: ObjectId;
    unit_name: string;
    unit_factor: number;
    currency_code: string;
    exchange_rate: number;
    quantity: number;
    unit_price: number;
    discount_amount?: number;
    discount_percentage?: number;
    total_discount_amount?: number;
    vat_calculation_type: VATCalculationType;
    vat_percentage: number;
    vat_amount: number;
    amount: number;
    amount_exclude_vat: number;
    status_code: SubscriptionLineStatusCode;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface ISubscriptionLineResult extends Partial<ISubscriptionLineDocument> {
}
export interface ISubscriptionLineSpec<T> extends Partial<Record<keyof ISubscriptionLineDocument, T>> {
}
export interface ISubscriptionLineInfo extends Omit<ISubscriptionLineDocument, BaseExtractFields> {
}
export interface ISubscriptionLineUpdateDocument extends ISubscriptionLineResult {
}
export interface ISubscriptionLineFilter extends ISubscriptionLineResult {
}
export interface ISubscriptionLineProjection extends ISubscriptionLineSpec<Projection> {
}
export interface ISubscriptionLineSort extends ISubscriptionLineSpec<Sort> {
}
