import { CompanyStatusCode, Projection, Sort, SubscriptionStatusCode } from '../../enum';
import { ObjectId } from 'mongodb';
import { IAppResult, ICurrencyResult } from '../general';
export interface ICompanySubscription {
    subscription_id: ObjectId;
    app_id: string;
    plan_id: string;
    status_code: SubscriptionStatusCode;
}
export interface ICompanyDocument {
    _id?: ObjectId;
    customer_id: ObjectId;
    customer_code?: string;
    name: string;
    business_type_id: ObjectId;
    slug: string;
    country_code: string;
    register_at: Date;
    registered_tax_no?: string;
    database_name: string;
    timezone: string;
    date_format?: string;
    subscriptions?: ICompanySubscription[];
    status_code: CompanyStatusCode;
    created_at: Date;
    updated_at?: Date;
}
export interface ICompanyResult extends Partial<ICompanyDocument> {
}
export interface ICompanySpec<T> extends Partial<Record<keyof ICompanyDocument, T>> {
}
export interface ICompanyInfo {
    customer_id: ObjectId;
    customer_code?: string;
    name: string;
    business_type_id?: string;
    country_code: string;
    registered_tax_no?: string;
    timezone?: string;
    date_format?: string;
    subscriptions?: ICompanySubscription[];
    status_code: CompanyStatusCode;
}
export interface ICompanyUpdateDocument extends ICompanyResult {
}
export interface ICompanyFilter extends ICompanyResult {
}
export interface ICompanyProjection extends ICompanySpec<Projection> {
}
export interface ICompanySort extends ICompanySpec<Sort> {
}
export interface ICompanyCached {
    _id: ObjectId;
    uuid: ObjectId;
    name: string;
    registered_tax_no: string;
    currency: ICurrencyResult;
    database_name: string;
    date_format: string;
    subscriptions?: ICompanySubscription[];
    app?: IAppResult;
    status_code: CompanyStatusCode;
}
