import { ObjectId } from 'mongodb';
import { PreferenceTypeCode, Projection, Sort } from '../../enum';
export interface ISalesConfig {
    config_sales_approval: boolean;
    notify_approver: boolean;
    notify_approval_submitter: boolean;
    sales_terms_condition: string;
    sales_customer_notes: string;
}
export interface IPurchaseConfig {
    config_purchase_approval: boolean;
    notify_approver: boolean;
    notify_approval_submitter: boolean;
}
export interface IInventoryConfig {
    config_inventory_approval: boolean;
    notify_approver: boolean;
    notify_approval_submitter: boolean;
    enable_lot_series_tracking: boolean;
}
export interface IPOSConfig {
    setup_shift: boolean;
    tax: {
        vat_id: ObjectId;
        vat_name: string;
        vat_rate: string;
    };
}
export interface ILoyaltyConfig {
    point_reward_conversion_rate: number;
    point_spend_conversion_rate: number;
}
export interface IBillingSubscriptionConfig {
    customer_notes: string;
    notify_email?: string;
    notify_email_cc?: string;
    bill_after_trial_expired: boolean;
}
export interface IBillingWebhookConfig {
    url: string;
    header?: string;
}
export interface IBillingConfig {
    subscription: IBillingSubscriptionConfig;
    webhook?: IBillingWebhookConfig;
}
export interface IPreferenceDocument {
    _id?: ObjectId;
    app_id: string;
    type_code: PreferenceTypeCode;
    config: ISalesConfig | IPurchaseConfig | IInventoryConfig | IPOSConfig | ILoyaltyConfig | IBillingConfig;
    created_at: Date;
    updated_at?: Date;
}
export interface IPreferenceResult extends Partial<IPreferenceDocument> {
}
export interface IPreferenceSpec<T> extends Partial<Record<keyof IPreferenceDocument, T>> {
}
export interface IPreferenceInfo extends Omit<IPreferenceDocument, '_id' | 'created_at' | 'updated_at'> {
}
export interface IPreferenceUpdateDocument extends IPreferenceResult {
}
export interface IPreferenceFilter extends IPreferenceResult {
}
export interface IPreferenceProjection extends IPreferenceSpec<Projection> {
}
export interface IPreferenceSort extends IPreferenceSpec<Sort> {
}
