import { ObjectId } from 'mongodb';
import { Projection, Sort, UserRoleTypeCode } from '../../enum';
export interface IRolePermission {
    code?: number;
    name?: string;
    read?: boolean;
    write?: boolean;
    menu_code?: number;
    more?: any;
    is_active: boolean;
}
export interface IRoleSubReport {
    code: number;
    report_code: number;
    name: string;
    read?: boolean;
    is_active: boolean;
}
export interface IRoleReport {
    code: number;
    report_code: number;
    name: string;
    read?: boolean;
    sub: IRoleSubReport[];
    is_active: boolean;
}
export interface IRoleSetting {
    code: number;
    setting_code: number;
    name: string;
    read?: boolean;
    is_active: boolean;
}
export interface IRoleInventory extends IRolePermission {
}
export interface IRoleInventoryRetailPOS extends IRolePermission {
}
export interface IRoleSales extends IRolePermission {
}
export interface IRolePurchase extends IRolePermission {
}
export interface IRoleMore extends IRolePermission {
}
export interface IInventoryUserPermission {
    dashboard: any[];
    inventory?: IRoleInventory[];
    sales?: IRoleSales[];
    purchase?: IRolePurchase[];
    pos?: IRoleInventoryRetailPOS[];
    more?: IRoleMore[];
    reports?: IRoleReport[];
    settings?: IRoleSetting[];
}
export interface IRetailPOSUserPermission extends IRolePermission {
}
export interface IRestaurantUserPermission extends IInventoryUserPermission {
}
export interface IRestaurantPOSUserPermission extends IRolePermission {
}
export interface IRestaurantKDSUserPermission extends IRolePermission {
}
export interface IRestaurantATOUserPermission extends IRolePermission {
}
export interface IRoleLoyalty extends IRolePermission {
}
export interface ILoyaltyUserPermission {
    dashboard: any[];
    loyalty?: IRoleLoyalty[];
    more?: IRoleMore[];
    reports?: IRoleReport[];
    settings?: IRoleSetting[];
}
export interface IRoleSubscription extends IRolePermission {
}
export interface ISubscriptionUserPermission {
    dashboard: any[];
    subscription?: IRoleSubscription[];
    sales?: IRoleSales[];
    more?: IRoleMore[];
    reports?: IRoleReport[];
    settings?: IRoleSetting[];
}
export interface IRoleDocument {
    _id?: ObjectId;
    code: string;
    name: string;
    description?: string;
    is_default: boolean;
    is_active: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by?: ObjectId;
}
export interface IRoleResult extends Partial<IRoleDocument> {
}
export interface IRoleSpec<T> extends Partial<Record<keyof IRoleDocument, T>> {
}
export interface IRoleInfo extends Omit<IRoleDocument, '_id' | 'created_at' | 'updated_at'> {
}
export interface IRoleUpdateDocument extends IRoleResult {
}
export interface IRoleFilter extends IRoleResult {
}
export interface IRoleProjection extends IRoleSpec<Projection> {
}
export interface IRoleSort extends IRoleSpec<Sort> {
}
export interface IUserRoleDocument {
    _id?: ObjectId;
    role_id: ObjectId;
    app_code: string;
    type_code: UserRoleTypeCode;
    permission: IInventoryUserPermission | IRetailPOSUserPermission | IRestaurantUserPermission | IRestaurantPOSUserPermission | IRestaurantKDSUserPermission | IRestaurantATOUserPermission | ILoyaltyUserPermission | ISubscriptionUserPermission;
    is_default: boolean;
    is_active: boolean;
    created_at: Date;
    created_by: ObjectId;
    updated_at?: Date;
    updated_by?: ObjectId;
}
export interface IUserRoleResult extends Partial<IUserRoleDocument> {
}
export interface IUserRoleSpec<T> extends Partial<Record<keyof IUserRoleDocument, T>> {
}
export interface IUserRoleInfo extends Omit<IUserRoleDocument, '_id' | 'created_at' | 'updated_at'> {
}
export interface IUserRoleUpdateDocument extends IUserRoleResult {
}
export interface IUserRoleFilter extends IUserRoleResult {
}
export interface IUserRoleProjection extends IUserRoleSpec<Projection> {
}
export interface IUserRoleSort extends IUserRoleSpec<Sort> {
}
