import { Gender, POSUserStatusCode, Projection, Sort, UserStatusCode } from '../../enum';
import { ObjectId } from 'mongodb';
import { IBranchDocument } from './branch.interface';
export interface IUserAccessBranch extends Pick<IBranchDocument, '_id' | 'name'> {
}
export interface IUserCurrentAccessBranch extends Pick<IBranchDocument, '_id' | 'name' | 'warehouse_id' | 'warehouse_name'> {
}
export interface IUserAppRole {
    role_id: ObjectId;
    app_id: string;
}
export interface IUserDocument {
    _id?: ObjectId;
    company_id: ObjectId;
    firstname: string;
    lastname: string;
    username: string;
    slug: string;
    gender: Gender;
    email: string;
    password: string;
    mobile_phone: string;
    photo?: string;
    per_page?: number;
    locale: string;
    timezone: string;
    is_owner: boolean;
    is_phone_verified: boolean;
    app_roles: IUserAppRole[];
    access_branches?: ObjectId[];
    status_code: UserStatusCode;
    created_at: Date;
    created_by?: ObjectId;
    updated_at?: Date;
    updated_by: ObjectId;
}
export interface IUserResult extends Partial<IUserDocument> {
}
export interface IUserSpec<T> extends Partial<Record<keyof IUserDocument, T>> {
}
export interface IUserInfo {
    company_id?: ObjectId;
    company_uuid?: ObjectId;
    firstname: string;
    lastname: string;
    gender: Gender;
    email: string;
    password: string;
    mobile_phone: string;
    photo: string;
    per_page?: number;
    locale: string;
    timezone: string;
    is_owner: boolean;
    is_phone_verified: boolean;
    app_roles?: IUserAppRole[];
    access_branches?: ObjectId[];
    created_by: ObjectId;
}
export interface IUserFilter extends IUserResult {
}
export interface IUserUpdateDocument extends IUserResult {
}
export interface IUserProjection extends IUserSpec<Projection> {
}
export interface IUserSort extends IUserSpec<Sort> {
}
export interface IJWTPayload {
    _id: string;
    email: string;
    user_uuid: string;
    uuid: string;
    hash?: string;
    iat?: number;
    exp?: number;
}
export interface IUserCached {
    _id: string;
    user_uuid: string;
    company_uuid: string;
    company_id: string;
    username: string;
    app_roles?: IUserAppRole[];
    app_role?: IUserAppRole;
    access_branches?: IUserAccessBranch[];
    current_access_branch?: IUserCurrentAccessBranch;
    per_page?: number;
    is_owner: boolean;
    status_code: UserStatusCode;
    pos_app_role?: IUserAppRole;
    pos_status_code?: POSUserStatusCode;
}
