import { Db, ClientSession, ObjectId, UpdateFilter, BulkWriteResult, PushOperator, PullOperator } from 'mongodb';
import { IDeleteResult, IUpdateResult, IInsertOneResult, IInsertManyResult } from '../interfaces/base.interface';
export default class Model<Document, UpdateDocument, Filter, Projection, Result, Sort, PushFilter = any, PullFilter = any, AggregateResult = any> {
    db: Db;
    name: string;
    constructor(db: Db, name: string);
    countDocuments(filters: Filter | object): Promise<number>;
    findDocumentById(id: ObjectId, projection?: Projection): Promise<Result>;
    findOneDocument(filter: Filter | object, projection?: Projection): Promise<Result>;
    findDocuments(filters: Filter | object, projection?: Projection, sort?: Sort): Promise<Result[]>;
    paginateDocument(filters: Filter | object, projection: Projection, sort: Sort, skip: number, limit: number): Promise<Result[]>;
    distinctDocuments<T>(field: string, filter: Filter, options?: any): Promise<T[]>;
    insertOneDocument(document: Document, isTransaction?: boolean, session?: ClientSession): Promise<IInsertOneResult<Result>>;
    insertManyDocuments(document: Document[] | any, isTransaction?: boolean, session?: ClientSession): Promise<IInsertManyResult>;
    updateOneDocument(document: UpdateDocument, filters: Filter, arrayFilters?: object, isTransaction?: boolean, session?: ClientSession): Promise<IUpdateResult>;
    updateManyDocuments(document: UpdateDocument, filters: Filter, arrayFilters: object, isTransaction?: boolean, session?: ClientSession): Promise<IUpdateResult>;
    rawUpdateOneDocument(document: UpdateFilter<UpdateDocument>, filters: Filter, arrayFilters?: object, isTransaction?: boolean, session?: ClientSession): Promise<IUpdateResult>;
    rawUpdateManyDocuments(document: UpdateFilter<UpdateDocument>, filters: Filter, arrayFilters: object, isTransaction?: boolean, session?: ClientSession): Promise<IUpdateResult>;
    deleteManyDocument(filters: Filter, isTransaction?: boolean, session?: ClientSession): Promise<IDeleteResult>;
    deleteOneDocument(filters: Filter, isTransaction?: boolean, session?: ClientSession): Promise<IDeleteResult>;
    pullDocuments(filters: Filter, pullFilter: PullOperator<PullFilter>, isTransaction?: boolean, session?: ClientSession): Promise<IUpdateResult>;
    pushDocuments(filters: Filter, pushFilter: PushOperator<PushFilter>, isTransaction?: boolean, session?: ClientSession): Promise<IUpdateResult>;
    bulkWriteDocuments(operation: any[], isTransaction?: boolean, session?: ClientSession): Promise<BulkWriteResult>;
    aggregateDocuments(pipeline: object[]): Promise<AggregateResult[]>;
}
