"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class Model {
    constructor(db, name) {
        this.db = db;
        this.name = name;
    }
    countDocuments(filters) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield this.db.collection(this.name).countDocuments(filters);
        });
    }
    findDocumentById(id, projection) {
        return __awaiter(this, void 0, void 0, function* () {
            const project = projection;
            let result;
            if (project) {
                result = yield this.db.collection(this.name).findOne({ _id: id }, { projection: project });
            }
            else {
                result = yield this.db.collection(this.name).findOne({ _id: id });
            }
            return result;
        });
    }
    findOneDocument(filter, projection) {
        return __awaiter(this, void 0, void 0, function* () {
            const project = projection;
            let result;
            if (project) {
                result = yield this.db.collection(this.name).findOne(filter, { projection: project });
            }
            else {
                result = yield this.db.collection(this.name).findOne(filter);
            }
            return result;
        });
    }
    findDocuments(filters, projection, sort) {
        return __awaiter(this, void 0, void 0, function* () {
            const project = projection;
            const sortBy = sort;
            let result;
            if (sort) {
                if (project) {
                    result = yield this.db.collection(this.name).find(filters).sort(sortBy).project(project).toArray();
                    return result;
                }
                result = yield this.db.collection(this.name).find(filters).sort(sortBy).toArray();
                return result;
            }
            if (project) {
                result = yield this.db.collection(this.name).find(filters).project(project).toArray();
                return result;
            }
            result = yield this.db.collection(this.name).find(filters).toArray();
            return result;
        });
    }
    paginateDocument(filters, projection, sort, skip, limit) {
        return __awaiter(this, void 0, void 0, function* () {
            const project = projection;
            const sortBy = sort;
            let result;
            if (sortBy) {
                if (projection) {
                    result = yield this.db
                        .collection(this.name)
                        .find(filters)
                        .sort(sortBy)
                        .project(project)
                        .skip(skip)
                        .limit(limit)
                        .toArray();
                    return result;
                }
                result = yield this.db.collection(this.name).find(filters).sort(sortBy).skip(skip).limit(limit).toArray();
                return result;
            }
            if (projection) {
                result = yield this.db
                    .collection(this.name)
                    .find(filters)
                    .project(project)
                    .skip(skip)
                    .limit(limit)
                    .toArray();
                return result;
            }
            result = yield this.db.collection(this.name).find(filters).skip(skip).limit(limit).toArray();
            return result;
        });
    }
    distinctDocuments(field, filter, options) {
        return __awaiter(this, void 0, void 0, function* () {
            let result;
            if (!options) {
                result = yield this.db.collection(this.name).distinct(field, filter);
            }
            else {
                result = yield this.db.collection(this.name).distinct(field, filter, options);
            }
            return result;
        });
    }
    insertOneDocument(document, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = yield this.db.collection(this.name).insertOne(document);
            }
            else {
                response = yield this.db.collection(this.name).insertOne(document, { session });
            }
            return {
                status: response.acknowledged === true ? 1 : 0,
                insertedCount: 1,
                insertedId: response.insertedId,
                document: Object.assign(Object.assign({}, document), { _id: response.insertedId }),
            };
        });
    }
    insertManyDocuments(document, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = yield this.db.collection(this.name).insertMany(document);
            }
            else {
                response = yield this.db.collection(this.name).insertMany(document, { session });
            }
            return {
                status: response.acknowledged === true ? 1 : 0,
                insertedCount: response.insertedCount,
                insertedIds: response.insertedIds,
            };
        });
    }
    updateOneDocument(document, filters, arrayFilters, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                if (arrayFilters) {
                    response = (yield this.db.collection(this.name).updateOne(filters, { $set: document }, {
                        arrayFilters: [arrayFilters],
                        session: session,
                    }));
                }
                else {
                    response = (yield this.db.collection(this.name).updateOne(filters, { $set: document }));
                }
            }
            else {
                if (arrayFilters) {
                    response = (yield this.db.collection(this.name).updateOne(filters, { $set: document }, {
                        arrayFilters: [arrayFilters],
                        session: session,
                    }));
                }
                else {
                    response = (yield this.db
                        .collection(this.name)
                        .updateOne(filters, { $set: document }, { session }));
                }
            }
            return { status: response.acknowledged === true ? 1 : 0, updatedCount: response.modifiedCount };
        });
    }
    updateManyDocuments(document, filters, arrayFilters, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                if (arrayFilters) {
                    response = (yield this.db
                        .collection(this.name)
                        .updateMany(filters, { $set: document }, { arrayFilters: [arrayFilters] }));
                }
                else {
                    response = (yield this.db
                        .collection(this.name)
                        .updateMany(filters, { $set: document }));
                }
            }
            else {
                if (arrayFilters) {
                    response = (yield this.db
                        .collection(this.name)
                        .updateMany(filters, { $set: document }, { arrayFilters: [arrayFilters], session: session }));
                }
                else {
                    response = (yield this.db
                        .collection(this.name)
                        .updateMany(filters, { $set: document }, { session: session }));
                }
            }
            return { status: response.acknowledged === true ? 1 : 0, updatedCount: response.modifiedCount };
        });
    }
    rawUpdateOneDocument(document, filters, arrayFilters, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                if (arrayFilters) {
                    response = (yield this.db.collection(this.name).updateOne(filters, document, {
                        arrayFilters: [arrayFilters],
                        session: session,
                    }));
                }
                else {
                    response = (yield this.db.collection(this.name).updateOne(filters, document));
                }
            }
            else {
                if (arrayFilters) {
                    response = (yield this.db.collection(this.name).updateOne(filters, document, {
                        arrayFilters: [arrayFilters],
                        session: session,
                    }));
                }
                else {
                    response = (yield this.db
                        .collection(this.name)
                        .updateOne(filters, document, { session }));
                }
            }
            return { status: response.acknowledged === true ? 1 : 0, updatedCount: response.modifiedCount };
        });
    }
    rawUpdateManyDocuments(document, filters, arrayFilters, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                if (arrayFilters) {
                    response = (yield this.db.collection(this.name).updateMany(filters, document, {
                        arrayFilters: [arrayFilters],
                    }));
                }
                else {
                    response = (yield this.db.collection(this.name).updateMany(filters, document));
                }
            }
            else {
                if (arrayFilters) {
                    response = (yield this.db.collection(this.name).updateMany(filters, document, {
                        arrayFilters: [arrayFilters],
                        session: session,
                    }));
                }
                else {
                    response = (yield this.db
                        .collection(this.name)
                        .updateMany(filters, document, { session: session }));
                }
            }
            return { status: response.acknowledged === true ? 1 : 0, updatedCount: response.modifiedCount };
        });
    }
    deleteManyDocument(filters, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = yield this.db.collection(this.name).deleteMany(filters);
            }
            else {
                response = yield this.db.collection(this.name).deleteMany(filters, { session: session });
            }
            return { status: response.acknowledged === true ? 1 : 0, deletedCount: response.deletedCount };
        });
    }
    deleteOneDocument(filters, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = yield this.db.collection(this.name).deleteOne(filters);
            }
            else {
                response = yield this.db.collection(this.name).deleteOne(filters, { session: session });
            }
            return { status: response.acknowledged === true ? 1 : 0, deletedCount: response.deletedCount };
        });
    }
    pullDocuments(filters, pullFilter, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = (yield this.db.collection(this.name).updateOne(filters, { $pull: pullFilter }));
            }
            else {
                response = (yield this.db
                    .collection(this.name)
                    .updateOne(filters, { $pull: pullFilter }, { session: session }));
            }
            return { status: response.acknowledged === true ? 1 : 0, updatedCount: response.modifiedCount };
        });
    }
    pushDocuments(filters, pushFilter, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = (yield this.db.collection(this.name).updateOne(filters, { $push: pushFilter }));
            }
            else {
                response = (yield this.db
                    .collection(this.name)
                    .updateOne(filters, { $push: pushFilter }, { session: session }));
            }
            return { status: response.acknowledged === true ? 1 : 0, updatedCount: response.modifiedCount };
        });
    }
    bulkWriteDocuments(operation, isTransaction, session) {
        return __awaiter(this, void 0, void 0, function* () {
            let response;
            if (!isTransaction) {
                response = yield this.db.collection(this.name).bulkWrite(operation);
            }
            else {
                response = yield this.db.collection(this.name).bulkWrite(operation, { session: session });
            }
            return response;
        });
    }
    aggregateDocuments(pipeline) {
        return __awaiter(this, void 0, void 0, function* () {
            const response = yield this.db.collection(this.name).aggregate(pipeline).toArray();
            return response;
        });
    }
}
exports.default = Model;
//# sourceMappingURL=base.model.js.map