"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class ApprovalRequest extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.ApprovalRequest);
    }
    make(info) {
        return {
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            type_code: info.type_code,
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            next_approver_id: new mongodb_1.ObjectId(info.next_approver_id),
            last_request_date: (0, utils_1.utcDateOnly)(info.last_request_date),
            requests: info.requests,
            actions: info.actions,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    documentType(documentTypeCode) {
        switch (documentTypeCode) {
            case enum_1.ApprovalDocumentTypeCode.InventoryAdjustment:
                return enum_1.ApprovalDocumentType.InventoryAdjustment;
            case enum_1.ApprovalDocumentTypeCode.TransferOrder:
                return enum_1.ApprovalDocumentType.TransferOrder;
            case enum_1.ApprovalDocumentTypeCode.PurchaseQuote:
                return enum_1.ApprovalDocumentType.PurchaseQuote;
            case enum_1.ApprovalDocumentTypeCode.PurchaseOrder:
                return enum_1.ApprovalDocumentType.PurchaseOrder;
            case enum_1.ApprovalDocumentTypeCode.PurchaseReturnOrder:
                return enum_1.ApprovalDocumentType.PurchaseReturnOrder;
            case enum_1.ApprovalDocumentTypeCode.SalesQuote:
                return enum_1.ApprovalDocumentType.SalesQuote;
            case enum_1.ApprovalDocumentTypeCode.SalesOrder:
                return enum_1.ApprovalDocumentType.SalesOrder;
            case enum_1.ApprovalDocumentTypeCode.SalesReturnOrder:
                return enum_1.ApprovalDocumentType.SalesReturnOrder;
            default:
                return null;
        }
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.ApprovalStatusCode.PendingApproval:
                return enum_1.ApprovalStatus.PendingApproval;
            case enum_1.ApprovalStatusCode.Approved:
                return enum_1.ApprovalStatus.Approved;
            case enum_1.ApprovalStatusCode.Rejected:
                return enum_1.ApprovalStatus.Rejected;
            default:
                return enum_1.ApprovalStatus.PendingApproval;
        }
    }
}
exports.default = ApprovalRequest;
//# sourceMappingURL=approval.request.model.js.map