"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const dayjs_1 = __importDefault(require("dayjs"));
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
const base_model_1 = __importDefault(require("../base.model"));
class BankLedgerEntry extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.BankLedgerEntry);
    }
    make(info) {
        return {
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            bank_account_id: new mongodb_1.ObjectId(info.bank_account_id),
            entry_date: (0, utils_1.utcDateOnly)((0, dayjs_1.default)().toString()),
            posting_date: info.posting_date ? (0, utils_1.utcDateOnly)(info.posting_date) : null,
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            document_date: info.document_date,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate || 1,
            amount: info.amount,
            is_deposit: info.is_deposit ? info.is_deposit : false,
            is_correction: info.is_correction ? info.is_correction : false,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
}
exports.default = BankLedgerEntry;
//# sourceMappingURL=bank.ledger.entry.model.js.map