"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
class DocumentNoSeriesHistory extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.DocumentNoSeriesHistory);
    }
    make(info) {
        return {
            document_no_series_id: new mongodb_1.ObjectId(info.document_no_series_id),
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            type_code: info.type_code,
            invoice_type_code: info.invoice_type_code,
            prefix: info.prefix,
            no_digit: info.no_digit || 10,
            starting_no: info.starting_no || 0,
            increment_by: info.increment_by || 1,
            last_used_no: info.last_used_no || 0,
            is_date_as_invoice: info.is_date_as_invoice ? info.is_date_as_invoice : false,
            is_auto_daily_reset: info.is_auto_daily_reset ? info.is_auto_daily_reset : false,
            is_custom: info.is_custom,
            created_at: new Date(),
        };
    }
    setDocumentNo(documents, documentNo, field = 'document_no') {
        for (let i = 0; i < documents.length; i += 1) {
            documents[i][field] = documentNo;
        }
        return documents;
    }
    type(typeCode) {
        switch (typeCode) {
            case enum_1.DocumentNoSeriesTypeCode.Vendor:
                return enum_1.DocumentNoSeriesType.Vendor;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseQuote:
                return enum_1.DocumentNoSeriesType.PurchaseQuote;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseOrder:
                return enum_1.DocumentNoSeriesType.PurchaseOrder;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseInvoice:
                return enum_1.DocumentNoSeriesType.PurchaseInvoice;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseReturnOrder:
                return enum_1.DocumentNoSeriesType.PurchaseReturnOrder;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseReceipt:
                return enum_1.DocumentNoSeriesType.PurchaseReceipt;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseInvoiced:
                return enum_1.DocumentNoSeriesType.PurchaseInvoiced;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseCreditMemo:
                return enum_1.DocumentNoSeriesType.PurchaseCreditMemo;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseShipment:
                return enum_1.DocumentNoSeriesType.PurchaseShipment;
            case enum_1.DocumentNoSeriesTypeCode.Payment:
                return enum_1.DocumentNoSeriesType.Payment;
            case enum_1.DocumentNoSeriesTypeCode.PaymentRefund:
                return enum_1.DocumentNoSeriesType.PaymentRefund;
            case enum_1.DocumentNoSeriesTypeCode.Customer:
                return enum_1.DocumentNoSeriesType.Customer;
            case enum_1.DocumentNoSeriesTypeCode.Salesperson:
                return enum_1.DocumentNoSeriesType.Salesperson;
            case enum_1.DocumentNoSeriesTypeCode.SalesQuote:
                return enum_1.DocumentNoSeriesType.SalesQuote;
            case enum_1.DocumentNoSeriesTypeCode.SalesOrder:
                return enum_1.DocumentNoSeriesType.SalesOrder;
            case enum_1.DocumentNoSeriesTypeCode.SalesReturnOrder:
                return enum_1.DocumentNoSeriesType.SalesReturnOrder;
            case enum_1.DocumentNoSeriesTypeCode.SalesShipment:
                return enum_1.DocumentNoSeriesType.SalesShipment;
            case enum_1.DocumentNoSeriesTypeCode.SalesPackage:
                return enum_1.DocumentNoSeriesType.SalesPackage;
            case enum_1.DocumentNoSeriesTypeCode.SalesInvoice:
                return enum_1.DocumentNoSeriesType.SalesInvoice;
            case enum_1.DocumentNoSeriesTypeCode.SalesReceipt:
                return enum_1.DocumentNoSeriesType.SalesReceipt;
            case enum_1.DocumentNoSeriesTypeCode.SalesCreditMemo:
                return enum_1.DocumentNoSeriesType.SalesCreditMemo;
            case enum_1.DocumentNoSeriesTypeCode.CashReceipt:
                return enum_1.DocumentNoSeriesType.CashReceipt;
            case enum_1.DocumentNoSeriesTypeCode.CashReceiptRefund:
                return enum_1.DocumentNoSeriesType.CashReceiptRefund;
            case enum_1.DocumentNoSeriesTypeCode.TransferOrder:
                return enum_1.DocumentNoSeriesType.TransferOrder;
            case enum_1.DocumentNoSeriesTypeCode.TransferShipment:
                return enum_1.DocumentNoSeriesType.TransferShipment;
            case enum_1.DocumentNoSeriesTypeCode.TransferReceipt:
                return enum_1.DocumentNoSeriesType.TransferReceipt;
            case enum_1.DocumentNoSeriesTypeCode.InventoryAdjustment:
                return enum_1.DocumentNoSeriesType.InventoryAdjustment;
            case enum_1.DocumentNoSeriesTypeCode.Subscription:
                return enum_1.DocumentNoSeriesType.Subscription;
            default:
                return null;
        }
    }
    invoiceType(invoiceTypeCode) {
        switch (invoiceTypeCode) {
            case enum_1.DocumentNoSeriesInvoiceTypeCode.PurchaseInvoice:
                return enum_1.DocumentNoSeriesInvoiceType.PurchaseInvoice;
            case enum_1.DocumentNoSeriesInvoiceTypeCode.SalesInvoice:
                return enum_1.DocumentNoSeriesInvoiceType.SalesInvoice;
            default:
                return null;
        }
    }
}
exports.default = DocumentNoSeriesHistory;
//# sourceMappingURL=document.no.series.history.model.js.map