"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
class DocumentNoSeries extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.DocumentNoSeries);
    }
    generateDocumentNo(typeCode_1, branchId_1) {
        return __awaiter(this, arguments, void 0, function* (typeCode, branchId, isTransaction = false, session) {
            const document = yield this.findOneDocument({ type_code: typeCode, branch_id: new mongodb_1.ObjectId(branchId) });
            if (!document) {
                return null;
            }
            const no = (document.starting_no + document.last_used_no + document.increment_by).toString();
            const documentNo = `${document.prefix}${no.padStart(document.no_digit, '0')}`;
            if (!isTransaction) {
                yield this.updateOneDocument({ last_used_no: document.last_used_no + document.increment_by }, { _id: document._id });
            }
            else {
                yield this.updateOneDocument({ last_used_no: document.last_used_no + document.increment_by }, { _id: document._id }, null, true, session);
            }
            return documentNo;
        });
    }
    make(info) {
        return {
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            type_code: info.type_code,
            prefix: info.prefix,
            no_digit: info.no_digit || 10,
            starting_no: info.starting_no || 0,
            increment_by: info.increment_by || 1,
            last_used_no: info.last_used_no || 0,
            is_date_as_invoice: info.is_date_as_invoice ? info.is_date_as_invoice : false,
            is_auto_daily_reset: info.is_auto_daily_reset ? info.is_auto_daily_reset : false,
            is_active: true,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info) {
        return {
            prefix: info.prefix,
            no_digit: info.no_digit,
            starting_no: info.starting_no,
            increment_by: info.increment_by,
            last_used_no: info.last_used_no,
            is_date_as_invoice: info.is_date_as_invoice ? info.is_date_as_invoice : false,
            is_auto_daily_reset: info.is_auto_daily_reset ? info.is_auto_daily_reset : false,
            updated_at: new Date(),
        };
    }
    setDocumentNo(documents, documentNo, field = 'document_no') {
        for (let i = 0; i < documents.length; i += 1) {
            documents[i][field] = documentNo;
        }
        return documents;
    }
    type(typeCode) {
        switch (typeCode) {
            case enum_1.DocumentNoSeriesTypeCode.Vendor:
                return enum_1.DocumentNoSeriesType.Vendor;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseQuote:
                return enum_1.DocumentNoSeriesType.PurchaseQuote;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseOrder:
                return enum_1.DocumentNoSeriesType.PurchaseOrder;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseInvoice:
                return enum_1.DocumentNoSeriesType.PurchaseInvoice;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseReturnOrder:
                return enum_1.DocumentNoSeriesType.PurchaseReturnOrder;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseReceipt:
                return enum_1.DocumentNoSeriesType.PurchaseReceipt;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseInvoiced:
                return enum_1.DocumentNoSeriesType.PurchaseInvoiced;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseCreditMemo:
                return enum_1.DocumentNoSeriesType.PurchaseCreditMemo;
            case enum_1.DocumentNoSeriesTypeCode.PurchaseShipment:
                return enum_1.DocumentNoSeriesType.PurchaseShipment;
            case enum_1.DocumentNoSeriesTypeCode.Payment:
                return enum_1.DocumentNoSeriesType.Payment;
            case enum_1.DocumentNoSeriesTypeCode.PaymentRefund:
                return enum_1.DocumentNoSeriesType.PaymentRefund;
            case enum_1.DocumentNoSeriesTypeCode.Customer:
                return enum_1.DocumentNoSeriesType.Customer;
            case enum_1.DocumentNoSeriesTypeCode.Salesperson:
                return enum_1.DocumentNoSeriesType.Salesperson;
            case enum_1.DocumentNoSeriesTypeCode.SalesQuote:
                return enum_1.DocumentNoSeriesType.SalesQuote;
            case enum_1.DocumentNoSeriesTypeCode.SalesOrder:
                return enum_1.DocumentNoSeriesType.SalesOrder;
            case enum_1.DocumentNoSeriesTypeCode.SalesReturnOrder:
                return enum_1.DocumentNoSeriesType.SalesReturnOrder;
            case enum_1.DocumentNoSeriesTypeCode.SalesShipment:
                return enum_1.DocumentNoSeriesType.SalesShipment;
            case enum_1.DocumentNoSeriesTypeCode.SalesPackage:
                return enum_1.DocumentNoSeriesType.SalesPackage;
            case enum_1.DocumentNoSeriesTypeCode.SalesInvoice:
                return enum_1.DocumentNoSeriesType.SalesInvoice;
            case enum_1.DocumentNoSeriesTypeCode.SalesReceipt:
                return enum_1.DocumentNoSeriesType.SalesReceipt;
            case enum_1.DocumentNoSeriesTypeCode.SalesCreditMemo:
                return enum_1.DocumentNoSeriesType.SalesCreditMemo;
            case enum_1.DocumentNoSeriesTypeCode.CashReceipt:
                return enum_1.DocumentNoSeriesType.CashReceipt;
            case enum_1.DocumentNoSeriesTypeCode.CashReceiptRefund:
                return enum_1.DocumentNoSeriesType.CashReceiptRefund;
            case enum_1.DocumentNoSeriesTypeCode.TransferOrder:
                return enum_1.DocumentNoSeriesType.TransferOrder;
            case enum_1.DocumentNoSeriesTypeCode.TransferShipment:
                return enum_1.DocumentNoSeriesType.TransferShipment;
            case enum_1.DocumentNoSeriesTypeCode.TransferReceipt:
                return enum_1.DocumentNoSeriesType.TransferReceipt;
            case enum_1.DocumentNoSeriesTypeCode.InventoryAdjustment:
                return enum_1.DocumentNoSeriesType.InventoryAdjustment;
            case enum_1.DocumentNoSeriesTypeCode.Subscription:
                return enum_1.DocumentNoSeriesType.Subscription;
            default:
                return null;
        }
    }
    invoiceType(invoiceTypeCode) {
        switch (invoiceTypeCode) {
            case enum_1.DocumentNoSeriesInvoiceTypeCode.PurchaseInvoice:
                return enum_1.DocumentNoSeriesInvoiceType.PurchaseInvoice;
            case enum_1.DocumentNoSeriesInvoiceTypeCode.SalesInvoice:
                return enum_1.DocumentNoSeriesInvoiceType.SalesInvoice;
            default:
                return null;
        }
    }
}
exports.default = DocumentNoSeries;
//# sourceMappingURL=document.no.series.model.js.map