"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
const base_model_1 = __importDefault(require("../base.model"));
class InventoryAdjustmentHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.InventoryAdjustmentHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            external_document_no: info.external_document_no || null,
            reason_id: new mongodb_1.ObjectId(info.reason_id),
            status_code: enum_1.AdjustmentStatusCode.Open,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info) {
        return {
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            external_document_no: info.external_document_no || null,
            reason_id: new mongodb_1.ObjectId(info.reason_id),
            notes: info.notes || null,
            updated_at: new Date(),
            updated_by: info.updated_by,
        };
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.AdjustmentStatusCode.Open:
                return enum_1.AdjustmentStatus.Open;
            case enum_1.AdjustmentStatusCode.PendingApproval:
                return enum_1.AdjustmentStatus.PendingApproval;
            case enum_1.AdjustmentStatusCode.Issued:
                return enum_1.AdjustmentStatus.Issued;
            case enum_1.AdjustmentStatusCode.Adjusted:
                return enum_1.AdjustmentStatus.Adjusted;
            case enum_1.AdjustmentStatusCode.Rejected:
                return enum_1.AdjustmentStatus.Rejected;
            default:
                return enum_1.AdjustmentStatus.Open;
        }
    }
}
exports.default = InventoryAdjustmentHeader;
//# sourceMappingURL=inventory.adjustment.header.model.js.map