"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const mongodb_1 = require("mongodb");
const utils_1 = require("../../utils");
class ItemLedgerEntry extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.ItemLedgerEntry);
    }
    make(info) {
        return {
            item_id: new mongodb_1.ObjectId(info.item_id),
            item_sku: info.item_sku,
            variant_id: info.variant_id ? new mongodb_1.ObjectId(info.variant_id) : null,
            is_variant: info.is_variant,
            posting_date: info.posting_date ? new Date(info.posting_date) : null,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            entry_type_code: info.entry_type_code,
            entry_date: new Date(),
            source_type_code: info.source_type_code,
            source_id: info.source_id,
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            document_date: new Date(info.document_date),
            order_id: new mongodb_1.ObjectId(info.order_id),
            order_type_code: info.order_type_code,
            order_no: info.order_no,
            order_date: new Date(info.order_date),
            order_line_id: new mongodb_1.ObjectId(info.order_line_id),
            external_document_no: info.external_document_no || null,
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            base_unit_id: new mongodb_1.ObjectId(info.base_unit_id),
            base_unit_name: info.base_unit_name,
            base_unit_factor: info.base_unit_factor,
            quantity: info.quantity,
            base_quantity: info.base_quantity,
            remaining_quantity: info.remaining_quantity,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            price: info.price,
            base_price: info.base_price,
            vat_amount: info.vat_amount,
            amount_exclude_vat: info.amount_exclude_vat,
            amount: info.amount,
            lot_no: info.lot_no || null,
            serial_no: info.serial_no || null,
            warranty_date: info.warranty_date ? (0, utils_1.utcDateOnly)(info.warranty_date) : null,
            expiration_date: info.expiration_date ? (0, utils_1.utcDateOnly)(info.expiration_date) : null,
            is_adjustment: info.is_adjustment,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
}
exports.default = ItemLedgerEntry;
//# sourceMappingURL=item.ledger.entry.model.js.map