"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
class ItemWarehouseTracking extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.ItemWarehouseTracking);
    }
    make(info) {
        return {
            item_id: new mongodb_1.ObjectId(info.item_id),
            variant_id: info.variant_id ? new mongodb_1.ObjectId(info.variant_id) : null,
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            stock_on_hand: info.stock_on_hand || 0,
            expired_stock: info.expired_stock || 0,
            sale_order_allocation: info.sale_order_allocation || 0,
            purchase_return_allocation: info.purchase_return_allocation || 0,
            adjustment_allocation: info.adjustment_allocation || 0,
            transfer_order_allocation: info.transfer_order_allocation || 0,
            reorder_quantity: info.reorder_quantity || 0,
            initial_stock: info.initial_stock || 0,
        };
    }
    committedStock(itemWarehouseTracking) {
        return (itemWarehouseTracking.sale_order_allocation +
            itemWarehouseTracking.purchase_return_allocation +
            itemWarehouseTracking.adjustment_allocation +
            itemWarehouseTracking.transfer_order_allocation);
    }
    stockAvailableForSale(itemWarehouseTracking) {
        return (itemWarehouseTracking.stock_on_hand -
            (itemWarehouseTracking.expired_stock + this.committedStock(itemWarehouseTracking)));
    }
}
exports.default = ItemWarehouseTracking;
//# sourceMappingURL=item.warehouse.tracking.model.js.map