"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
const base_model_1 = __importDefault(require("../base.model"));
class TransferOrderHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.TransferOrderHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_ids: info.warehouse_ids,
            from_warehouse_id: new mongodb_1.ObjectId(info.from_warehouse_id),
            in_transit_warehouse_id: new mongodb_1.ObjectId(info.in_transit_warehouse_id),
            to_warehouse_id: new mongodb_1.ObjectId(info.to_warehouse_id),
            external_document_no: info.external_document_no || null,
            reason_id: info.reason_id ? new mongodb_1.ObjectId(info.reason_id) : null,
            total_amount: info.total_amount,
            status_code: enum_1.TransferStatusCode.Open,
            shipped_status_code: enum_1.TransferStatusCode.NotShipped,
            received_status_code: enum_1.TransferStatusCode.NotReceived,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info) {
        return {
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            warehouse_ids: info.warehouse_ids,
            from_warehouse_id: new mongodb_1.ObjectId(info.from_warehouse_id),
            to_warehouse_id: new mongodb_1.ObjectId(info.to_warehouse_id),
            external_document_no: info.external_document_no || null,
            reason_id: info.reason_id ? new mongodb_1.ObjectId(info.reason_id) : null,
            total_amount: info.total_amount,
            notes: info.notes || null,
            updated_at: new Date(),
            updated_by: info.updated_by,
        };
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.TransferStatusCode.Open:
                return enum_1.TransferStatus.Open;
            case enum_1.TransferStatusCode.PendingApproval:
                return enum_1.TransferStatus.PendingApproval;
            case enum_1.TransferStatusCode.Issued:
                return enum_1.TransferStatus.Issued;
            case enum_1.TransferStatusCode.NotShipped:
                return enum_1.TransferStatus.NotShipped;
            case enum_1.TransferStatusCode.PartiallyShipped:
                return enum_1.TransferStatus.PartiallyShipped;
            case enum_1.TransferStatusCode.Shipped:
                return enum_1.TransferStatus.Shipped;
            case enum_1.TransferStatusCode.NotReceived:
                return enum_1.TransferStatus.NotReceived;
            case enum_1.TransferStatusCode.PartiallyReceived:
                return enum_1.TransferStatus.PartiallyReceived;
            case enum_1.TransferStatusCode.Received:
                return enum_1.TransferStatus.Received;
            case enum_1.TransferStatusCode.InTransit:
                return enum_1.TransferStatus.InTransit;
            case enum_1.TransferStatusCode.Transferred:
                return enum_1.TransferStatus.Transferred;
            case enum_1.TransferStatusCode.Closed:
                return enum_1.TransferStatus.Closed;
            default:
                return enum_1.TransferStatus.Open;
        }
    }
}
exports.default = TransferOrderHeader;
//# sourceMappingURL=transfer.order.header.model.js.map