"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_model_1 = __importDefault(require("../base.model"));
const utils_1 = require("../../utils");
const enum_1 = require("../../enum");
class LoyaltyPromotion extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.LoyaltyPromotion);
    }
    make(info) {
        return {
            branches: info.branches,
            name: info.name,
            promotion_type_code: info.promotion_type_code,
            psp_ids: info.psp_ids,
            apply_for_customer_code: info.apply_for_customer_code,
            customer_ids: info.customer_ids,
            customer_group_ids: info.customer_group_ids,
            apply_for_item_code: info.apply_for_item_code,
            items: info.items,
            item_categories: info.item_categories || [],
            min_quantity: info.min_quantity || 0,
            discount_percentage: info.discount_percentage || 0,
            discount_amount: info.discount_amount || 0,
            start_date: info.start_date ? (0, utils_1.utcDateOnly)(info.start_date) : null,
            end_date: info.end_date ? (0, utils_1.utcDateOnly)(info.end_date) : null,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info) {
        return {
            branches: info.branches,
            name: info.name,
            promotion_type_code: info.promotion_type_code,
            psp_ids: info.psp_ids,
            apply_for_customer_code: info.apply_for_customer_code,
            customer_ids: info.customer_ids,
            customer_group_ids: info.customer_group_ids,
            apply_for_item_code: info.apply_for_item_code,
            items: info.items,
            item_categories: info.item_categories || [],
            min_quantity: info.min_quantity || 0,
            discount_percentage: info.discount_percentage || 0,
            discount_amount: info.discount_amount || 0,
            start_date: info.start_date ? (0, utils_1.utcDateOnly)(info.start_date) : null,
            end_date: info.end_date ? (0, utils_1.utcDateOnly)(info.end_date) : null,
            updated_at: new Date(),
            updated_by: info.updated_by,
        };
    }
    promotionType(promotionTypeCode) {
        switch (promotionTypeCode) {
            case enum_1.LoyaltyPromotionTypeCode.Discount:
                return enum_1.LoyaltyPromotionType.Discount;
            case enum_1.LoyaltyPromotionTypeCode.BuyItemsAndFreeItems:
                return enum_1.LoyaltyPromotionType.BuyItemsAndFreeItems;
            case enum_1.LoyaltyPromotionTypeCode.BuyItemsGetSpecialPrice:
                return enum_1.LoyaltyPromotionType.BuyItemsGetSpecialPrice;
            case enum_1.LoyaltyPromotionTypeCode.PaymentServiceProviderDiscount:
                return enum_1.LoyaltyPromotionType.PaymentServiceProviderDiscount;
            default:
                return enum_1.LoyaltyPromotionType.Discount;
        }
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.LoyaltyPromotionStatusCode.Draft:
                return enum_1.LoyaltyPromotionStatus.Draft;
            case enum_1.LoyaltyPromotionStatusCode.Scheduled:
                return enum_1.LoyaltyPromotionStatus.Scheduled;
            case enum_1.LoyaltyPromotionStatusCode.Ongoing:
                return enum_1.LoyaltyPromotionStatus.Ongoing;
            case enum_1.LoyaltyPromotionStatusCode.Suspended:
                return enum_1.LoyaltyPromotionStatus.Suspended;
            case enum_1.LoyaltyPromotionStatusCode.Expired:
                return enum_1.LoyaltyPromotionStatus.Expired;
            default:
                return enum_1.LoyaltyPromotionStatus.Draft;
        }
    }
    promotionApplyForCustomer(code) {
        switch (code) {
            case enum_1.LoyaltyApplyCustomerCode.AllCustomers:
                return enum_1.LoyaltyApplyCustomer.AllCustomers;
            case enum_1.LoyaltyApplyCustomerCode.Customers:
                return enum_1.LoyaltyApplyCustomer.Customers;
            case enum_1.LoyaltyApplyCustomerCode.CustomerGroup:
                return enum_1.LoyaltyApplyCustomer.CustomerGroup;
            default:
                return enum_1.LoyaltyApplyCustomer.Customers;
        }
    }
    promotionApplyForItem(code) {
        switch (code) {
            case enum_1.LoyaltyApplyItemCode.AllItems:
                return enum_1.LoyaltyApplyItem.AllItems;
            case enum_1.LoyaltyApplyItemCode.Items:
                return enum_1.LoyaltyApplyItem.Items;
            case enum_1.LoyaltyApplyItemCode.ItemCategories:
                return enum_1.LoyaltyApplyItem.ItemCategories;
            default:
                return enum_1.LoyaltyApplyItem.Items;
        }
    }
    freeType(code) {
        switch (code) {
            case enum_1.LoyaltyPromotionFreeTypeCode.FreeBasedOnBuyQuantity:
                return enum_1.LoyaltyPromotionFreeType.FreeBasedOnBuyQuantity;
            case enum_1.LoyaltyPromotionFreeTypeCode.FreeSpecificQuantity:
                return enum_1.LoyaltyPromotionFreeType.FreeSpecificQuantity;
            default:
                return enum_1.LoyaltyPromotionFreeType.None;
        }
    }
}
exports.default = LoyaltyPromotion;
//# sourceMappingURL=loyalty.promotion.model.js.map