"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class LoyaltyReward extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.LoyaltyReward);
    }
    make(info) {
        return {
            reward_type_code: info.reward_type_code,
            item_id: new mongodb_1.ObjectId(info.item_id),
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            unit_price: info.unit_price,
            start_date: info.start_date ? (0, utils_1.utcDateOnly)(info.start_date) : null,
            expire_date: info.expire_date ? (0, utils_1.utcDateOnly)(info.expire_date) : null,
            has_transaction: false,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    rewardType(rewardTypeCode) {
        switch (rewardTypeCode) {
            case enum_1.LoyaltyRewardTypeCode.RedeemableItem:
                return enum_1.LoyaltyRewardType.RedeemableItem;
            default:
                return enum_1.LoyaltyRewardType.RedeemableItem;
        }
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.LoyaltyRewardStatusCode.Redeemable:
                return enum_1.LoyaltyRewardStatus.Redeemable;
            case enum_1.LoyaltyRewardStatusCode.Expired:
                return enum_1.LoyaltyRewardStatus.Expired;
            default:
                return enum_1.LoyaltyRewardStatus.Expired;
        }
    }
}
exports.default = LoyaltyReward;
//# sourceMappingURL=loyalty.reward.model.js.map