"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class LoyaltyVoucher extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.LoyaltyVoucher);
    }
    make(info) {
        return {
            name: info.name,
            codes: info.codes,
            discount_percentage: info.discount_percentage || 0,
            discount_amount: info.discount_amount || 0,
            is_free_shipping: info.is_free_shipping,
            apply_for_customer_code: info.apply_for_customer_code,
            customer_ids: info.customer_ids,
            customer_group_ids: info.customer_group_ids,
            apply_for_item_code: info.apply_for_item_code,
            item_ids: info.item_ids,
            item_categories_ids: info.item_categories_ids,
            start_date: info.start_date ? (0, utils_1.utcDateOnly)(info.start_date) : null,
            expire_date: info.expire_date ? (0, utils_1.utcDateOnly)(info.expire_date) : null,
            limit_type_code: info.limit_type_code,
            limit_usage: info.limit_usage || 0,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info) {
        return {
            name: info.name,
            codes: info.codes,
            discount_percentage: info.discount_percentage || 0,
            discount_amount: info.discount_amount || 0,
            is_free_shipping: info.is_free_shipping,
            apply_for_customer_code: info.apply_for_customer_code,
            customer_ids: info.customer_ids,
            customer_group_ids: info.customer_group_ids,
            apply_for_item_code: info.apply_for_item_code,
            item_ids: info.item_ids,
            item_categories_ids: info.item_categories_ids,
            start_date: info.start_date ? (0, utils_1.utcDateOnly)(info.start_date) : null,
            expire_date: info.expire_date ? (0, utils_1.utcDateOnly)(info.expire_date) : null,
            limit_type_code: info.limit_type_code,
            limit_usage: info.limit_usage || 0,
            updated_by: info.updated_by,
            updated_at: new Date(),
        };
    }
    voucherStatus(statusCode) {
        switch (statusCode) {
            case enum_1.LoyaltyVoucherStatusCode.Draft:
                return enum_1.LoyaltyVoucherStatus.Draft;
            case enum_1.LoyaltyVoucherStatusCode.Published:
                return enum_1.LoyaltyVoucherStatus.Published;
            case enum_1.LoyaltyVoucherStatusCode.Expired:
                return enum_1.LoyaltyVoucherStatus.Expired;
            case enum_1.LoyaltyVoucherStatusCode.Unpublished:
                return enum_1.LoyaltyVoucherStatus.Unpublished;
            default:
                return enum_1.LoyaltyVoucherStatus.Draft;
        }
    }
    voucherLimitType(typeCode) {
        switch (typeCode) {
            case enum_1.LoyaltyVoucherLimitTypeCode.Unlimited:
                return enum_1.LoyaltyVoucherLimitType.Unlimited;
            case enum_1.LoyaltyVoucherLimitTypeCode.Limit:
                return enum_1.LoyaltyVoucherLimitType.Limit;
            case enum_1.LoyaltyVoucherLimitTypeCode.LimitPerCustomer:
                return enum_1.LoyaltyVoucherLimitType.LimitPerCustomer;
            default:
                return enum_1.LoyaltyVoucherLimitType.LimitPerCustomer;
        }
    }
    voucherApplyForCustomer(code) {
        switch (code) {
            case enum_1.LoyaltyApplyCustomerCode.AllCustomers:
                return enum_1.LoyaltyApplyCustomer.AllCustomers;
            case enum_1.LoyaltyApplyCustomerCode.Customers:
                return enum_1.LoyaltyApplyCustomer.Customers;
            case enum_1.LoyaltyApplyCustomerCode.CustomerGroup:
                return enum_1.LoyaltyApplyCustomer.CustomerGroup;
            default:
                return enum_1.LoyaltyApplyCustomer.Customers;
        }
    }
    voucherApplyForItem(code) {
        switch (code) {
            case enum_1.LoyaltyApplyItemCode.AllItems:
                return enum_1.LoyaltyApplyItem.AllItems;
            case enum_1.LoyaltyApplyItemCode.Items:
                return enum_1.LoyaltyApplyItem.Items;
            case enum_1.LoyaltyApplyItemCode.ItemCategories:
                return enum_1.LoyaltyApplyItem.ItemCategories;
            default:
                return enum_1.LoyaltyApplyItem.Items;
        }
    }
}
exports.default = LoyaltyVoucher;
//# sourceMappingURL=loyalty.voucher.model.js.map