"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
class Media extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.Media);
    }
    make(info) {
        return {
            app_id: info.app_id,
            filename: info.filename,
            type_code: info.type_code,
            mime_type: info.mime_type,
            dimension: info.dimension,
            size: info.size,
            dominant_color: info.dominant_color || null,
            blur_hash: info.blur_hash,
            url: info.url || null,
            share_type_code: info.share_type_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    type(code) {
        switch (code) {
            case enum_1.MediaTypeCode.Image:
                return enum_1.MediaType.Image;
            case enum_1.MediaTypeCode.File:
                return enum_1.MediaType.File;
            default:
                return enum_1.MediaType.None;
        }
    }
    shareType(code) {
        switch (code) {
            case enum_1.MediaShareTypeCode.Everyone:
                return enum_1.MediaShareType.Everyone;
            case enum_1.MediaShareTypeCode.Users:
                return enum_1.MediaShareType.Users;
            default:
                return enum_1.MediaShareType.None;
        }
    }
    list(ids, baseURL, projection) {
        return __awaiter(this, void 0, void 0, function* () {
            const mediaDocuments = yield this.findDocuments({ _id: { $in: ids } }, projection);
            const mediaRes = [];
            for (const mediaDoc of mediaDocuments) {
                mediaRes.push(Object.assign(Object.assign({}, mediaDoc), { url: `${baseURL}/${mediaDoc._id}/${mediaDoc.filename}` }));
            }
            return mediaRes;
        });
    }
}
exports.default = Media;
//# sourceMappingURL=media.model.js.map