"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
const utils_1 = require("../../utils");
class Reservation extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.Reservation);
    }
    make(info) {
        return {
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            reservation_channel_code: info.reservation_channel_code,
            reservation_date: (0, utils_1.utcDateOnly)(info.reservation_date),
            start_time: info.start_time,
            end_time: info.end_time,
            floors: info.floors,
            reason: info.reason || null,
            notes: info.notes || null,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    status(code) {
        switch (code) {
            case enum_1.ReservationStatusCode.Confirmed:
                return enum_1.ReservationStatus.Confirmed;
            case enum_1.ReservationStatusCode.Seated:
                return enum_1.ReservationStatus.Seated;
            case enum_1.ReservationStatusCode.Cancelled:
                return enum_1.ReservationStatus.Cancelled;
            default:
                return enum_1.ReservationStatus.Void;
        }
    }
}
exports.default = Reservation;
//# sourceMappingURL=reservation.model.js.map