"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
class PaymentMethod extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.PaymentMethod);
    }
    make(info) {
        return {
            name: info.name,
            description: info.description || null,
            type_code: info.type_code,
            bank_account_id: info.bank_account_id ? new mongodb_1.ObjectId(info.bank_account_id) : null,
            image: info.image || null,
            has_transaction: false,
            is_active: info.is_active,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    type(code) {
        switch (code) {
            case enum_1.PaymentMethodTypeCode.Cash:
                return enum_1.PaymentMethodType.Cash;
            case enum_1.PaymentMethodTypeCode.Bank:
                return enum_1.PaymentMethodType.Bank;
            case enum_1.PaymentMethodTypeCode.OnlinePayment:
                return enum_1.PaymentMethodType.OnlinePayment;
            default:
                return enum_1.PaymentMethodType.Cash;
        }
    }
}
exports.default = PaymentMethod;
//# sourceMappingURL=payment.method.model.js.map