"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class PurchaseCreditMemoHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.PurchaseCreditMemoHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            tax_invoice_no: info.tax_invoice_no || null,
            order_id: new mongodb_1.ObjectId(info.order_id),
            order_no: info.order_no,
            order_date: info.order_date,
            order_type_code: info.order_type_code,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            registered_tax_no: info.registered_tax_no || null,
            external_document_no: info.external_document_no || null,
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            vendor_id: new mongodb_1.ObjectId(info.vendor_id),
            payment_term_id: info.payment_term_id || null,
            payment_term_disc_per: info.payment_term_disc_per || null,
            payment_term_num_of_day: info.payment_term_num_of_day || null,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            discount_level_type: info.discount_level_type,
            discount_amount: info.discount_amount,
            discount_percentage: info.discount_percentage,
            total_discount_amount: info.total_discount_amount,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: info.vat_id,
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            total_remaining_amount: info.total_remaining_amount,
            total_payment: info.total_payment || 0,
            ref_payment_journals: info.ref_payment_journals || [],
            total_applied_inv_amount: info.total_applied_inv_amount || 0,
            applied_invoices: info.applied_invoices || [],
            status_code: info.status_code,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.RefundStatusCode.Open:
                return enum_1.RefundStatus.Open;
            case enum_1.RefundStatusCode.PartiallyRefund:
                return enum_1.RefundStatus.PartiallyRefund;
            case enum_1.RefundStatusCode.Refunded:
                return enum_1.RefundStatus.Refunded;
            default:
                return enum_1.RefundStatus.Open;
        }
    }
}
exports.default = PurchaseCreditMemoHeader;
//# sourceMappingURL=purchase.credit.memo.header.model.js.map