"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class PurchaseInvoiceLine extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.PurchaseInvoiceLine);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            tax_invoice_no: info.tax_invoice_no || null,
            order_id: new mongodb_1.ObjectId(info.order_id),
            order_no: info.order_no,
            order_type_code: info.order_type_code,
            order_date: info.order_date,
            order_line_id: new mongodb_1.ObjectId(info.order_line_id),
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            vendor_id: new mongodb_1.ObjectId(info.vendor_id),
            item_id: new mongodb_1.ObjectId(info.item_id),
            item_type_code: info.item_type_code,
            item_sku: info.item_sku,
            variant_id: info.variant_id ? new mongodb_1.ObjectId(info.variant_id) : null,
            category_id: new mongodb_1.ObjectId(info.unit_id),
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            base_unit_id: new mongodb_1.ObjectId(info.base_unit_id),
            base_unit_name: info.base_unit_name,
            base_unit_factor: info.base_unit_factor,
            quantity: info.quantity,
            base_quantity: info.base_quantity,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            cost_price: info.cost_price,
            base_cost_price: info.base_cost_price,
            discount_amount: info.discount_amount,
            discount_percentage: info.discount_percentage,
            total_discount_amount: info.total_discount_amount,
            vat_calculation_type: info.vat_calculation_type,
            vat_percentage: info.vat_percentage,
            vat_amount: info.vat_amount,
            amount: info.amount,
            amount_exclude_vat: info.amount_exclude_vat,
            remaining_amount: info.remaining_amount,
            applied_payment_amount: info.applied_payment_amount || 0,
            applied_credit_memo_amount: info.applied_credit_memo_amount || 0,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
}
exports.default = PurchaseInvoiceLine;
//# sourceMappingURL=purchase.invoice.line.model.js.map