"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class PurchaseOrderHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.PurchaseOrderHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            ref_document_id: info.ref_document_id ? new mongodb_1.ObjectId(info.ref_document_id) : null,
            ref_document_no: info.ref_document_no || null,
            ref_document_type_code: info.ref_document_type_code || null,
            external_document_no: info.external_document_no || null,
            order_date: (0, utils_1.utcDateOnly)(info.order_date),
            document_due_date: info.document_due_date ? (0, utils_1.utcDateOnly)(info.document_due_date) : null,
            expected_delivery_date: info.expected_delivery_date
                ? (0, utils_1.utcDateOnly)(info.expected_delivery_date)
                : null,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            vendor_id: new mongodb_1.ObjectId(info.vendor_id),
            shipping_address: info.shipping_address || null,
            shipping_city: info.shipping_city || null,
            shipping_state: info.shipping_state || null,
            shipping_zip_code: info.shipping_zip_code || null,
            shipping_phone: info.shipping_phone || null,
            payment_term_id: info.payment_term_id ? new mongodb_1.ObjectId(info.payment_term_id) : null,
            payment_term_name: info.payment_term_name,
            payment_term_dis_per: info.payment_term_dis_per,
            payment_term_num_of_day: info.payment_term_num_of_day,
            shipment_agent_id: info.shipment_agent_id ? new mongodb_1.ObjectId(info.shipment_agent_id) : null,
            shipment_agent_name: info.shipment_agent_name || null,
            external_ref_shipment_no: info.external_ref_shipment_no || null,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            discount_level_type: info.discount_level_type || enum_1.DiscountLevelType.AtTransactionLevel,
            discount_amount: info.discount_amount || 0,
            discount_percentage: info.discount_percentage || 0,
            total_discount_amount: info.total_discount_amount || 0,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: new mongodb_1.ObjectId(info.vat_id),
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            status_code: enum_1.PurchaseDocumentStatusCode.Open,
            total_received_amount: info.total_received_amount || 0,
            received_status_code: info.received_status_code || enum_1.PurchaseDocumentStatusCode.NotReceived,
            total_invoiced_amount: info.total_invoiced_amount || 0,
            invoiced_status_code: info.invoiced_status_code || enum_1.PurchaseDocumentStatusCode.NotInvoiced,
            total_shipped_amount: info.total_shipped_amount || 0,
            shipped_status_code: info.shipped_status_code || enum_1.PurchaseDocumentStatusCode.NotShipped,
            total_credit_memo_amount: info.total_credit_memo_amount || 0,
            credit_memo_status_code: info.credit_memo_status_code || enum_1.PurchaseDocumentStatusCode.NotCreditMemo,
            notes: info.notes,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info) {
        return {
            ref_document_id: info.ref_document_id ? new mongodb_1.ObjectId(info.ref_document_id) : null,
            ref_document_no: info.ref_document_no || null,
            ref_document_type_code: info.ref_document_type_code || null,
            external_document_no: info.external_document_no || null,
            order_date: (0, utils_1.utcDateOnly)(info.order_date),
            document_due_date: (0, utils_1.utcDateOnly)(info.document_due_date),
            expected_delivery_date: info.expected_delivery_date
                ? (0, utils_1.utcDateOnly)(info.expected_delivery_date)
                : null,
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            vendor_id: new mongodb_1.ObjectId(info.vendor_id),
            shipping_address: info.shipping_address || null,
            shipping_city: info.shipping_city || null,
            shipping_state: info.shipping_state || null,
            shipping_zip_code: info.shipping_zip_code || null,
            shipping_phone: info.shipping_phone || null,
            payment_term_id: info.payment_term_id ? new mongodb_1.ObjectId(info.payment_term_id) : null,
            payment_term_name: info.payment_term_name,
            payment_term_dis_per: info.payment_term_dis_per,
            payment_term_num_of_day: info.payment_term_num_of_day,
            shipment_agent_id: info.shipment_agent_id ? new mongodb_1.ObjectId(info.shipment_agent_id) : null,
            shipment_agent_name: info.shipment_agent_name || null,
            external_ref_shipment_no: info.external_ref_shipment_no || null,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            discount_level_type: info.discount_level_type || enum_1.DiscountLevelType.AtTransactionLevel,
            discount_amount: info.discount_amount || 0,
            discount_percentage: info.discount_percentage || 0,
            total_discount_amount: info.total_discount_amount || 0,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: new mongodb_1.ObjectId(info.vat_id),
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            status_code: enum_1.PurchaseDocumentStatusCode.Open,
            total_received_amount: info.total_received_amount || 0,
            received_status_code: info.received_status_code || enum_1.PurchaseDocumentStatusCode.NotReceived,
            total_invoiced_amount: info.total_invoiced_amount || 0,
            invoiced_status_code: info.invoiced_status_code || enum_1.PurchaseDocumentStatusCode.NotInvoiced,
            total_shipped_amount: info.total_shipped_amount || 0,
            shipped_status_code: info.shipped_status_code || enum_1.PurchaseDocumentStatusCode.NotShipped,
            total_credit_memo_amount: info.total_credit_memo_amount || 0,
            credit_memo_status_code: info.credit_memo_status_code || enum_1.PurchaseDocumentStatusCode.NotCreditMemo,
            notes: info.notes,
            updated_at: new Date(),
            updated_by: info.updated_by,
        };
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.PurchaseDocumentStatusCode.Open:
                return enum_1.PurchaseDocumentStatus.Open;
            case enum_1.PurchaseDocumentStatusCode.PendingApproval:
                return enum_1.PurchaseDocumentStatus.PendingApproval;
            case enum_1.PurchaseDocumentStatusCode.Rejected:
                return enum_1.PurchaseDocumentStatus.Rejected;
            case enum_1.PurchaseDocumentStatusCode.Issued:
                return enum_1.PurchaseDocumentStatus.Issued;
            case enum_1.PurchaseDocumentStatusCode.NotShipped:
                return enum_1.PurchaseDocumentStatus.NotShipped;
            case enum_1.PurchaseDocumentStatusCode.PartiallyShipped:
                return enum_1.PurchaseDocumentStatus.PartiallyShipped;
            case enum_1.PurchaseDocumentStatusCode.Shipped:
                return enum_1.PurchaseDocumentStatus.Shipped;
            case enum_1.PurchaseDocumentStatusCode.NotReceived:
                return enum_1.PurchaseDocumentStatus.NotReceived;
            case enum_1.PurchaseDocumentStatusCode.PartiallyReceived:
                return enum_1.PurchaseDocumentStatus.PartiallyReceived;
            case enum_1.PurchaseDocumentStatusCode.Received:
                return enum_1.PurchaseDocumentStatus.Received;
            case enum_1.PurchaseDocumentStatusCode.NotInvoiced:
                return enum_1.PurchaseDocumentStatus.NotInvoiced;
            case enum_1.PurchaseDocumentStatusCode.PartiallyInvoiced:
                return enum_1.PurchaseDocumentStatus.PartiallyInvoiced;
            case enum_1.PurchaseDocumentStatusCode.Invoiced:
                return enum_1.PurchaseDocumentStatus.Invoiced;
            case enum_1.PurchaseDocumentStatusCode.NotCreditMemo:
                return enum_1.PurchaseDocumentStatus.NotCreditMemo;
            case enum_1.PurchaseDocumentStatusCode.PartiallyCreditMemo:
                return enum_1.PurchaseDocumentStatus.PartiallyCreditMemo;
            case enum_1.PurchaseDocumentStatusCode.CreditMemo:
                return enum_1.PurchaseDocumentStatus.CreditMemo;
            case enum_1.PurchaseDocumentStatusCode.Closed:
                return enum_1.PurchaseDocumentStatus.Closed;
            default:
                return enum_1.PurchaseDocumentStatus.Open;
        }
    }
}
exports.default = PurchaseOrderHeader;
//# sourceMappingURL=purchase.order.header.model.js.map