"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class PurchaseOrderLine extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.PurchaseOrderLine);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            order_date: (0, utils_1.utcDateOnly)(info.order_date),
            vendor_id: new mongodb_1.ObjectId(info.vendor_id),
            item_id: new mongodb_1.ObjectId(info.item_id),
            item_type_code: info.item_type_code,
            item_sku: info.item_sku,
            variant_id: info.variant_id ? new mongodb_1.ObjectId(info.variant_id) : null,
            category_id: new mongodb_1.ObjectId(info.unit_id),
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            base_unit_id: new mongodb_1.ObjectId(info.base_unit_id),
            base_unit_name: info.base_unit_name,
            base_unit_factor: info.base_unit_factor,
            quantity: info.quantity,
            base_quantity: info.base_quantity,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            cost_price: info.cost_price,
            base_cost_price: info.base_cost_price,
            discount_amount: info.discount_amount || 0,
            discount_percentage: info.discount_percentage || 0,
            total_discount_amount: info.total_discount_amount || 0,
            vat_calculation_type: info.vat_calculation_type,
            vat_percentage: info.vat_percentage,
            vat_amount: info.vat_amount,
            amount: info.amount,
            amount_exclude_vat: info.amount_exclude_vat,
            quantity_to_receive: info.document_type_code === enum_1.PurchaseDocumentTypeCode.Order ? info.quantity : 0,
            quantity_received: 0,
            quantity_to_invoice: 0,
            quantity_invoiced: 0,
            quantity_to_ship: info.document_type_code === enum_1.PurchaseDocumentTypeCode.ReturnOrder ? info.quantity : 0,
            quantity_shipped: 0,
            quantity_to_credit_memo: 0,
            quantity_credit_memo: 0,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
}
exports.default = PurchaseOrderLine;
//# sourceMappingURL=purchase.order.line.model.js.map