"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
const utils_1 = require("../../utils");
class CashReceipt extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.CashReceipt);
    }
    make(info) {
        return {
            document_no: info.document_no,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            type_code: info.type_code,
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            posting_date: info.posting_date ? (0, utils_1.utcDateOnly)(info.posting_date) : null,
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            payment_method_id: new mongodb_1.ObjectId(info.payment_method_id),
            bank_account_id: info.bank_account_id ? new mongodb_1.ObjectId(info.bank_account_id) : null,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            amount: info.amount,
            remaining_amount: info.remaining_amount,
            total_discount_amount: info.total_discount_amount,
            applied_cash_receipt_source: info.applied_cash_receipt_source,
            is_deposit: info.is_deposit,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    appliedCashReceiptDocumentType(documentTypeCode) {
        switch (documentTypeCode) {
            case enum_1.SalesDocumentTypeCode.Invoice:
                return enum_1.SalesDocumentType.Invoice;
            case enum_1.SalesDocumentTypeCode.CreditMemo:
                return enum_1.SalesDocumentType.CreditMemo;
            default:
                return enum_1.SalesDocumentType.Invoice;
        }
    }
}
exports.default = CashReceipt;
//# sourceMappingURL=cash.receipt.model.js.map