"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
class Customer extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.Customer);
    }
    make(info) {
        return {
            code: info.code,
            salutation: info.salutation || null,
            first_name: info.first_name,
            last_name: info.last_name,
            username: `${info.first_name} ${info.last_name}`,
            company_name: info.company_name || null,
            email: info.email || null,
            contact_no: info.contact_no || [],
            bank_accounts: info.bank_accounts || [],
            social_apps: info.social_apps || [],
            currency_code: info.currency_code,
            credit_limit: info.credit_limit || -1,
            outstanding_balance: info.outstanding_balance || 0,
            outstanding_balance_bcy: info.outstanding_balance_bcy || 0,
            credit_balance: info.credit_balance || 0,
            credit_balance_bcy: info.credit_balance_bcy || 0,
            payment_term_id: info.payment_term_id ? new mongodb_1.ObjectId(info.payment_term_id) : null,
            shipment_agent_id: info.shipment_agent_id ? new mongodb_1.ObjectId(info.shipment_agent_id) : null,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_id: new mongodb_1.ObjectId(info.vat_id),
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            billing_addresses: info.billing_addresses || [],
            shipping_addresses: info.shipping_addresses || [],
            customer_group_id: info.customer_group_id ? new mongodb_1.ObjectId(info.customer_group_id) : null,
            is_general_customer: info.is_general_customer,
            has_transaction: false,
            is_active: info.is_active,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    makeUpdate(info, document) {
        const updateDocument = {
            salutation: info.salutation || null,
            first_name: info.first_name,
            last_name: info.last_name,
            username: `${info.first_name} ${info.last_name}`,
            company_name: info.company_name || null,
            email: info.email || null,
            contact_no: info.contact_no || [],
            bank_accounts: info.bank_accounts || [],
            social_apps: info.social_apps || [],
            currency_code: info.currency_code,
            credit_limit: info.credit_limit || -1,
            payment_term_id: info.payment_term_id ? new mongodb_1.ObjectId(info.payment_term_id) : null,
            shipment_agent_id: info.shipment_agent_id ? new mongodb_1.ObjectId(info.shipment_agent_id) : null,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_id: new mongodb_1.ObjectId(info.vat_id),
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            billing_addresses: info.billing_addresses || [],
            shipping_addresses: info.shipping_addresses || [],
            customer_group_id: info.customer_group_id ? new mongodb_1.ObjectId(info.customer_group_id) : null,
            has_transaction: false,
            is_active: info.is_active,
            updated_at: new Date(),
            updated_by: info.updated_by,
        };
        if (!document.has_transaction) {
            updateDocument.first_name = info.first_name;
            updateDocument.last_name = info.last_name;
            updateDocument.username = `${info.first_name} ${info.last_name}`;
        }
        return updateDocument;
    }
}
exports.default = Customer;
//# sourceMappingURL=customer.model.js.map