"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
const base_model_1 = __importDefault(require("../base.model"));
class SalesCreditMemoHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SalesCreditMemoHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: enum_1.SalesDocumentTypeCode.CreditMemo,
            tax_invoice_no: info.tax_invoice_no || null,
            order_id: new mongodb_1.ObjectId(info.order_id),
            order_no: info.order_no,
            order_type_code: info.order_type_code,
            order_date: info.order_date,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            registered_tax_no: info.registered_tax_no || null,
            external_document_no: info.external_document_no || null,
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_group_id: info.customer_group_id ? new mongodb_1.ObjectId(info.customer_group_id) : null,
            salesperson_id: info.salesperson_id ? new mongodb_1.ObjectId(info.salesperson_id) : null,
            sales_channel_code: info.sales_channel_code || null,
            payment_term_id: new mongodb_1.ObjectId(info.payment_term_id),
            currency_code: info.currency_code || null,
            exchange_rate: info.exchange_rate,
            discount_level_type: info.discount_level_type,
            discount_percentage: info.discount_percentage,
            discount_amount: info.discount_amount,
            total_discount_amount: info.total_discount_amount,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: info.vat_id,
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            total_remaining_amount: info.total_remaining_amount,
            total_cash_receipt: info.total_cash_receipt || 0,
            ref_cash_receipt_journals: info.ref_cash_receipt_journals || [],
            total_applied_inv_amount: info.total_applied_inv_amount || 0,
            applied_invoices: info.applied_invoices || [],
            status_code: info.status_code,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.CashReceiptRefundStatusCode.Open:
                return enum_1.CashReceiptRefundStatus.Open;
            case enum_1.CashReceiptRefundStatusCode.PartiallyRefund:
                return enum_1.CashReceiptRefundStatus.PartiallyRefund;
            case enum_1.CashReceiptRefundStatusCode.Refunded:
                return enum_1.CashReceiptRefundStatus.Refunded;
            default:
                return enum_1.CashReceiptRefundStatus.Open;
        }
    }
}
exports.default = SalesCreditMemoHeader;
//# sourceMappingURL=sales.credit.memo.header.model.js.map