"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
const base_model_1 = __importDefault(require("../base.model"));
class SalesOrderHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SalesOrderHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            ref_document_id: info.ref_document_id ? new mongodb_1.ObjectId(info.ref_document_id) : null,
            ref_document_no: info.ref_document_no || null,
            ref_document_type_code: info.ref_document_type_code || null,
            registered_tax_no: info.registered_tax_no || null,
            external_document_no: info.external_document_no || null,
            order_date: (0, utils_1.utcDateOnly)(info.order_date),
            document_due_date: info.document_due_date ? (0, utils_1.utcDateOnly)(info.document_due_date) : null,
            expected_delivery_date: info.expected_delivery_date
                ? (0, utils_1.utcDateOnly)(info.expected_delivery_date)
                : null,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_group_id: info.customer_group_id ? new mongodb_1.ObjectId(info.customer_group_id) : null,
            salesperson_id: info.salesperson_id ? new mongodb_1.ObjectId(info.salesperson_id) : null,
            sales_channel_code: info.sales_channel_code || null,
            shipping_address: info.shipping_address || null,
            shipping_city: info.shipping_city || null,
            shipping_state: info.shipping_state || null,
            shipping_zip_code: info.shipping_zip_code || null,
            shipping_phone: info.shipping_phone || null,
            billing_address: info.shipping_address || null,
            billing_city: info.shipping_city || null,
            billing_state: info.shipping_state || null,
            billing_zip_code: info.shipping_zip_code || null,
            billing_phone: info.shipping_phone || null,
            payment_term_id: new mongodb_1.ObjectId(info.payment_term_id),
            shipment_agent_id: info.shipment_agent_id ? new mongodb_1.ObjectId(info.shipment_agent_id) : null,
            external_ref_shipment_no: info.external_ref_shipment_no || null,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            discount_level_type: info.discount_level_type || enum_1.DiscountLevelType.AtTransactionLevel,
            discount_percentage: info.discount_percentage || 0,
            discount_amount: info.discount_amount || 0,
            total_discount_amount: info.total_discount_amount || 0,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: new mongodb_1.ObjectId(info.vat_id),
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            status_code: info.status_code,
            total_packaged_amount: info.total_packaged_amount || 0,
            package_status_code: info.package_status_code,
            total_shipped_amount: info.total_shipped_amount || 0,
            shipped_status_code: info.shipped_status_code,
            total_invoiced_amount: info.total_invoiced_amount || 0,
            invoiced_status_code: info.invoiced_status_code,
            total_received_amount: info.total_received_amount || 0,
            received_status_code: info.received_status_code,
            total_credit_memo_amount: info.total_credit_memo_amount || 0,
            credit_memo_status_code: info.credit_memo_status_code,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    status(statusCode) {
        switch (statusCode) {
            case enum_1.SalesDocumentStatusCode.Open:
                return enum_1.SalesDocumentStatus.Open;
            case enum_1.SalesDocumentStatusCode.PendingApproval:
                return enum_1.SalesDocumentStatus.PendingApproval;
            case enum_1.SalesDocumentStatusCode.Rejected:
                return enum_1.SalesDocumentStatus.Rejected;
            case enum_1.SalesDocumentStatusCode.Issued:
                return enum_1.SalesDocumentStatus.Issued;
            case enum_1.SalesDocumentStatusCode.NotShipped:
                return enum_1.SalesDocumentStatus.NotShipped;
            case enum_1.SalesDocumentStatusCode.PartiallyShipped:
                return enum_1.SalesDocumentStatus.PartiallyShipped;
            case enum_1.SalesDocumentStatusCode.Shipped:
                return enum_1.SalesDocumentStatus.Shipped;
            case enum_1.SalesDocumentStatusCode.NotReceived:
                return enum_1.SalesDocumentStatus.NotReceived;
            case enum_1.SalesDocumentStatusCode.PartiallyReceived:
                return enum_1.SalesDocumentStatus.PartiallyReceived;
            case enum_1.SalesDocumentStatusCode.Received:
                return enum_1.SalesDocumentStatus.Received;
            case enum_1.SalesDocumentStatusCode.NotInvoiced:
                return enum_1.SalesDocumentStatus.NotInvoiced;
            case enum_1.SalesDocumentStatusCode.PartiallyInvoiced:
                return enum_1.SalesDocumentStatus.PartiallyInvoiced;
            case enum_1.SalesDocumentStatusCode.Invoiced:
                return enum_1.SalesDocumentStatus.Invoiced;
            case enum_1.SalesDocumentStatusCode.NotCreditMemo:
                return enum_1.SalesDocumentStatus.NotCreditMemo;
            case enum_1.SalesDocumentStatusCode.PartiallyCreditMemo:
                return enum_1.SalesDocumentStatus.PartiallyCreditMemo;
            case enum_1.SalesDocumentStatusCode.CreditMemo:
                return enum_1.SalesDocumentStatus.CreditMemo;
            case enum_1.SalesDocumentStatusCode.Closed:
                return enum_1.SalesDocumentStatus.Closed;
            default:
                return enum_1.SalesDocumentStatus.Open;
        }
    }
}
exports.default = SalesOrderHeader;
//# sourceMappingURL=sales.order.header.model.js.map