"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
const base_model_1 = __importDefault(require("../base.model"));
class SalesOrderLine extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SalesOrderLine);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: info.document_type_code,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            order_date: (0, utils_1.utcDateOnly)(info.order_date),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_group_id: info.customer_group_id ? new mongodb_1.ObjectId(info.customer_group_id) : null,
            sales_channel_code: info.sales_channel_code || null,
            item_id: new mongodb_1.ObjectId(info.item_id),
            item_type_code: info.item_type_code,
            item_sku: info.item_sku,
            variant_id: info.variant_id ? new mongodb_1.ObjectId(info.variant_id) : null,
            category_id: new mongodb_1.ObjectId(info.unit_id),
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            base_unit_id: new mongodb_1.ObjectId(info.base_unit_id),
            base_unit_name: info.base_unit_name,
            base_unit_factor: info.base_unit_factor,
            quantity: info.quantity,
            base_quantity: info.base_quantity,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            unit_price: info.unit_price,
            base_unit_price: info.base_unit_price,
            discount_percentage: info.discount_percentage || 0,
            discount_amount: info.discount_amount || 0,
            total_discount_amount: info.total_discount_amount || 0,
            vat_calculation_type: info.vat_calculation_type,
            vat_percentage: info.vat_percentage,
            vat_amount: info.vat_amount,
            amount: info.amount,
            amount_exclude_vat: info.amount_exclude_vat || 0,
            quantity_to_package: info.quantity_to_package,
            quantity_packaged: info.quantity_packaged,
            quantity_to_ship: info.quantity_to_ship || 0,
            quantity_shipped: info.quantity_shipped || 0,
            quantity_to_invoice: info.quantity_to_invoice || 0,
            quantity_invoiced: info.quantity_invoiced || 0,
            quantity_to_receive: info.quantity_to_receive || 0,
            quantity_received: info.quantity_received || 0,
            quantity_to_credit_memo: info.quantity_to_credit_memo || 0,
            quantity_credit_memo: info.quantity_credit_memo || 0,
            attributes: info.attributes || null,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
}
exports.default = SalesOrderLine;
//# sourceMappingURL=sales.order.line.model.js.map