"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class SalesShipmentHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SalesShipmentHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            document_type_code: enum_1.SalesDocumentTypeCode.Shipment,
            order_id: new mongodb_1.ObjectId(info.order_id),
            order_no: info.order_no,
            order_type_code: info.order_type_code,
            order_date: info.order_date,
            app_id: info.app_id,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            warehouse_id: new mongodb_1.ObjectId(info.warehouse_id),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_group_id: info.customer_group_id ? new mongodb_1.ObjectId(info.customer_group_id) : null,
            sales_channel_code: info.sales_channel_code || null,
            external_document_no: info.external_document_no || null,
            document_date: (0, utils_1.utcDateOnly)(info.document_date),
            packages_no: info.packages_no || [],
            shipment_agent_id: info.shipment_agent_id ? new mongodb_1.ObjectId(info.shipment_agent_id) : null,
            shipping_address: info.shipping_address || null,
            shipping_city: info.shipping_city || null,
            shipping_state: info.shipping_state || null,
            shipping_zip_code: info.shipping_zip_code || null,
            shipping_phone: info.shipping_phone || null,
            tracking_no: info.tracking_no || null,
            tracking_url: info.tracking_url || null,
            shipping_charges: info.shipping_charges || 0,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            discount_level_type: info.discount_level_type,
            discount_amount: info.discount_amount,
            discount_percentage: info.discount_percentage,
            total_discount_amount: info.total_discount_amount,
            tax_type: info.tax_type,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: info.vat_id,
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            is_from_package: info.is_from_package,
            delivered_at: info.delivered_at ? (0, utils_1.utcDateOnly)(info.delivered_at) : null,
            status_code: info.status_code,
            notes: info.notes || null,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
}
exports.default = SalesShipmentHeader;
//# sourceMappingURL=sales.shipment.header.model.js.map