"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class SubscriptionEvent extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SubscriptionEvent);
    }
    make(info) {
        return {
            event_date: (0, utils_1.utcDateOnly)(info.event_date),
            event_type_code: info.event_type_code,
            event_source_code: info.event_source_code,
            request_count: info.request_count,
            payload: info.payload,
            webhook: info.webhook,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    eventType(code) {
        switch (code) {
            case enum_1.SubscriptionEventTypeCode.Created:
                return enum_1.SubscriptionEventType.Created;
            case enum_1.SubscriptionEventTypeCode.TrialExpired:
                return enum_1.SubscriptionEventType.TrialExpired;
            case enum_1.SubscriptionEventTypeCode.Active:
                return enum_1.SubscriptionEventType.Active;
            case enum_1.SubscriptionEventTypeCode.Ahead:
                return enum_1.SubscriptionEventType.Ahead;
            case enum_1.SubscriptionEventTypeCode.Renewed:
                return enum_1.SubscriptionEventType.Renewed;
            case enum_1.SubscriptionEventTypeCode.BillingDateChanged:
                return enum_1.SubscriptionEventType.BillingDateChanged;
            case enum_1.SubscriptionEventTypeCode.Upgraded:
                return enum_1.SubscriptionEventType.Upgraded;
            case enum_1.SubscriptionEventTypeCode.Downgraded:
                return enum_1.SubscriptionEventType.Downgraded;
            case enum_1.SubscriptionEventTypeCode.Unpaid:
                return enum_1.SubscriptionEventType.Unpaid;
            case enum_1.SubscriptionEventTypeCode.Cancelled:
                return enum_1.SubscriptionEventType.Cancelled;
            case enum_1.SubscriptionEventTypeCode.Reactivated:
                return enum_1.SubscriptionEventType.Reactivated;
            case enum_1.SubscriptionEventTypeCode.CancellationScheduled:
                return enum_1.SubscriptionEventType.CancellationScheduled;
            case enum_1.SubscriptionEventTypeCode.Expiring:
                return enum_1.SubscriptionEventType.Expiring;
            case enum_1.SubscriptionEventTypeCode.Deleted:
                return enum_1.SubscriptionEventType.Deleted;
            case enum_1.SubscriptionEventTypeCode.InvoiceCreated:
                return enum_1.SubscriptionEventType.InvoiceCreated;
            case enum_1.SubscriptionEventTypeCode.CashReceiptReceived:
                return enum_1.SubscriptionEventType.CashReceiptReceived;
            case enum_1.SubscriptionEventTypeCode.CashReceiptRefunded:
                return enum_1.SubscriptionEventType.CashReceiptRefunded;
            case enum_1.SubscriptionEventTypeCode.CashReceiptDeclined:
                return enum_1.SubscriptionEventType.CashReceiptDeclined;
            default:
                return enum_1.SubscriptionEventType.Created;
        }
    }
    eventSource(code) {
        switch (code) {
            case enum_1.SubscriptionEventSourceCode.System:
                return enum_1.SubscriptionEventSource.System;
            case enum_1.SubscriptionEventSourceCode.User:
                return enum_1.SubscriptionEventSource.User;
            default:
                return enum_1.SubscriptionEventSource.System;
        }
    }
}
exports.default = SubscriptionEvent;
//# sourceMappingURL=subscription.event.model.js.map