"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class SubscriptionHeader extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SubscriptionHeader);
    }
    make(info) {
        return {
            document_no: info.document_no,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_group_id: new mongodb_1.ObjectId(info.customer_group_id),
            product_id: new mongodb_1.ObjectId(info.product_id),
            plan_id: new mongodb_1.ObjectId(info.plan_id),
            billing_interval_code: info.billing_interval_code,
            billing_cycle_code: info.billing_cycle_code,
            salesperson_id: info.salesperson_id ? new mongodb_1.ObjectId(info.salesperson_id) : null,
            initialed_at: (0, utils_1.utcDateOnly)(info.initialed_at),
            activated_at: (0, utils_1.utcDateOnly)(info.activated_at),
            started_at: (0, utils_1.utcDateOnly)(info.started_at),
            expired_at: (0, utils_1.utcDateOnly)(info.expired_at),
            trial_period: info.trial_period || 0,
            trial_expired_at: info.trial_expired_at ? (0, utils_1.utcDateOnly)(info.trial_expired_at) : null,
            last_billing_at: info.last_billing_at ? (0, utils_1.utcDateOnly)(info.last_billing_at) : null,
            next_billing_at: (0, utils_1.utcDateOnly)(info.next_billing_at),
            suspended_at: info.suspended_at ? (0, utils_1.utcDateOnly)(info.suspended_at) : null,
            last_upgraded_at: info.last_upgraded_at ? (0, utils_1.utcDateOnly)(info.last_upgraded_at) : null,
            last_downgraded_at: info.last_downgraded_at ? (0, utils_1.utcDateOnly)(info.last_downgraded_at) : null,
            payment_term_id: info.payment_term_id ? new mongodb_1.ObjectId(info.payment_term_id) : null,
            is_metered_billing: info.is_metered_billing,
            remaining_billing_cycle: info.remaining_billing_cycle,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            voucher_code: info.voucher_code || null,
            discount_level_type: info.discount_level_type,
            discount_amount: info.discount_amount || 0,
            discount_percentage: info.discount_percentage || 0,
            total_discount_amount: info.total_discount_amount,
            tax_type_code: info.tax_type_code,
            vat_type: info.vat_type,
            vat_calculation_type: info.vat_calculation_type,
            vat_id: info.vat_id,
            vat_name: info.vat_name,
            vat_percentage: info.vat_percentage,
            total_vat_amount: info.total_vat_amount,
            total_amount: info.total_amount,
            total_amount_exclude_vat: info.total_amount_exclude_vat,
            customer_notes: info.customer_notes || null,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    status(code) {
        switch (code) {
            case enum_1.SubscriptionStatusCode.Draft:
                return enum_1.SubscriptionStatus.Draft;
            case enum_1.SubscriptionStatusCode.Trial:
                return enum_1.SubscriptionStatus.Trial;
            case enum_1.SubscriptionStatusCode.TrialExpired:
                return enum_1.SubscriptionStatus.TrialExpired;
            case enum_1.SubscriptionStatusCode.Active:
                return enum_1.SubscriptionStatus.Active;
            case enum_1.SubscriptionStatusCode.Unpaid:
                return enum_1.SubscriptionStatus.Unpaid;
            case enum_1.SubscriptionStatusCode.NonRenewing:
                return enum_1.SubscriptionStatus.NonRenewing;
            case enum_1.SubscriptionStatusCode.ScheduledCancel:
                return enum_1.SubscriptionStatus.ScheduledCancel;
            case enum_1.SubscriptionStatusCode.Cancelled:
                return enum_1.SubscriptionStatus.Cancelled;
            case enum_1.SubscriptionStatusCode.Suspended:
                return enum_1.SubscriptionStatus.Suspended;
            default:
                return enum_1.SubscriptionStatus.Expired;
        }
    }
    billingCycle(code) {
        return (0, utils_1.billingCycle)(code);
    }
}
exports.default = SubscriptionHeader;
//# sourceMappingURL=subscription.header.model.js.map