"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils");
class SubscriptionLine extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.SubscriptionLine);
    }
    make(info) {
        return {
            document_no: info.document_no,
            branch_id: new mongodb_1.ObjectId(info.branch_id),
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_group_id: new mongodb_1.ObjectId(info.customer_group_id),
            product_id: new mongodb_1.ObjectId(info.product_id),
            plan_id: new mongodb_1.ObjectId(info.plan_id),
            addon_id: info.addon_id ? new mongodb_1.ObjectId(info.addon_id) : null,
            billing_cycle_code: info.billing_cycle_code,
            item_type_code: info.item_type_code,
            category_id: new mongodb_1.ObjectId(info.unit_id),
            unit_id: new mongodb_1.ObjectId(info.unit_id),
            unit_name: info.unit_name,
            unit_factor: info.unit_factor,
            currency_code: info.currency_code,
            exchange_rate: info.exchange_rate,
            quantity: info.quantity,
            unit_price: info.unit_price,
            discount_amount: info.discount_amount || 0,
            discount_percentage: info.discount_percentage || 0,
            total_discount_amount: info.total_discount_amount,
            vat_calculation_type: info.vat_calculation_type,
            vat_percentage: info.vat_percentage,
            vat_amount: info.vat_amount,
            amount: info.amount,
            amount_exclude_vat: info.amount_exclude_vat,
            status_code: info.status_code,
            created_at: new Date(),
            created_by: info.created_by,
            updated_at: null,
            updated_by: null,
        };
    }
    status(code) {
        switch (code) {
            case enum_1.SubscriptionLineStatusCode.Pending:
                return enum_1.SubscriptionLineStatus.Pending;
            case enum_1.SubscriptionLineStatusCode.Active:
                return enum_1.SubscriptionLineStatus.Active;
            default:
                return enum_1.SubscriptionLineStatus.Pending;
        }
    }
    billingCycle(code) {
        return (0, utils_1.billingCycle)(code);
    }
}
exports.default = SubscriptionLine;
//# sourceMappingURL=subscription.line.model.js.map