"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const base_model_1 = __importDefault(require("../base.model"));
const enum_1 = require("../../enum");
const utils_1 = require("../../utils/utils");
const utils_2 = require("../../utils");
class Company extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.Company);
    }
    make(info) {
        return {
            customer_id: new mongodb_1.ObjectId(info.customer_id),
            customer_code: info.customer_code,
            name: info.name,
            business_type_id: new mongodb_1.ObjectId(info.business_type_id),
            slug: (0, utils_1.slug)(info.name, '_'),
            country_code: info.country_code,
            registered_tax_no: info.registered_tax_no || null,
            database_name: (0, utils_1.slug)(info.name, '_'),
            register_at: (0, utils_2.utcDateOnly)(new Date().toDateString()),
            timezone: info.timezone || null,
            date_format: info.date_format,
            subscriptions: info.subscriptions || [],
            status_code: info.status_code,
            created_at: new Date(),
            updated_at: null,
        };
    }
    status(code) {
        switch (code) {
            case enum_1.CompanyStatusCode.Pending:
                return enum_1.CompanyStatus.Pending;
            case enum_1.CompanyStatusCode.Verified:
                return enum_1.CompanyStatus.Verified;
            case enum_1.CompanyStatusCode.Active:
                return enum_1.CompanyStatus.Active;
            case enum_1.CompanyStatusCode.Suspended:
                return enum_1.CompanyStatus.Suspended;
            default:
                return enum_1.CompanyStatus.Pending;
        }
    }
}
exports.default = Company;
//# sourceMappingURL=company.model.js.map