"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const enum_1 = require("../../enum");
const base_model_1 = __importDefault(require("../base.model"));
const utils_1 = require("../../utils/utils");
class User extends base_model_1.default {
    constructor(db) {
        super(db, enum_1.Collections.User);
    }
    set hash(val) {
        this._hash = val;
    }
    get hash() {
        return this._hash;
    }
    make(info) {
        const _password = (0, utils_1.hashPassword)(info.password, this._hash);
        return {
            company_id: info.company_id,
            firstname: info.firstname,
            lastname: info.lastname,
            username: `${info.firstname} ${info.lastname}`,
            slug: `${info.firstname}${info.lastname}`.toLowerCase(),
            gender: info.gender,
            email: info.email.toLowerCase(),
            password: _password,
            mobile_phone: info.mobile_phone,
            photo: null,
            per_page: info.per_page || 10,
            locale: info.locale,
            timezone: info.timezone,
            is_owner: info.is_owner,
            is_phone_verified: false,
            app_roles: info.app_roles || [],
            access_branches: info.access_branches || [],
            status_code: enum_1.UserStatusCode.NotVerified,
            created_by: info.created_by || null,
            created_at: new Date(),
            updated_by: null,
            updated_at: null,
        };
    }
    status(code) {
        switch (code) {
            case enum_1.UserStatusCode.NotVerified:
                return enum_1.UserStatus.NotVerified;
            case enum_1.UserStatusCode.Active:
                return enum_1.UserStatus.Active;
            case enum_1.UserStatusCode.Away:
                return enum_1.UserStatus.Away;
            case enum_1.UserStatusCode.Inactive:
                return enum_1.UserStatus.Inactive;
            case enum_1.UserStatusCode.Suspended:
                return enum_1.UserStatus.Suspended;
            default:
                return enum_1.UserStatus.NotVerified;
        }
    }
}
exports.default = User;
//# sourceMappingURL=user.model.js.map