"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
class DeleteUseCase {
    constructor(db, model, deleteKey = '_id', filterWithBranch = true) {
        this.db = db;
        this.model = model;
        this.deleteKey = deleteKey;
        this.filterWithBranch = filterWithBranch;
    }
    exec(id, userInfo) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = new this.model(this.db);
            const filter = {};
            filter[this.deleteKey] = new mongodb_1.ObjectId(id);
            if (this.filterWithBranch) {
                filter['branch_id'] = new mongodb_1.ObjectId(userInfo.current_access_branch._id);
            }
            const queryDocument = yield model.findOneDocument(filter);
            if (!queryDocument) {
                return { notFound: true };
            }
            if (queryDocument.has_transaction) {
                return { hasTransaction: true };
            }
            const deletedResult = yield model.deleteOneDocument(filter);
            if (deletedResult.status !== 1 || deletedResult.deletedCount <= 0) {
                return { failedToDelete: true };
            }
            return { success: true };
        });
    }
}
exports.default = DeleteUseCase;
//# sourceMappingURL=delete.base.usecase.js.map