"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
class GetPostedDocumentByDocumentNoUseCase {
    constructor(db, headerModel, lineModel, filterWithBranch = true, lineProjection = {}) {
        this.lineProjection = {};
        this.db = db;
        this.headerModel = headerModel;
        this.lineModel = lineModel;
        this.filterWithBranch = filterWithBranch;
        this.lineProjection = lineProjection;
    }
    exec(documentNo, includeLineDocuments, userInfo) {
        return __awaiter(this, void 0, void 0, function* () {
            const header = new this.headerModel(this.db);
            let filter = { document_no: documentNo };
            if (this.filterWithBranch) {
                filter = Object.assign(Object.assign({}, filter), { branch_id: new mongodb_1.ObjectId(userInfo.current_access_branch._id) });
            }
            const headerDocument = yield header.findOneDocument(filter);
            if (!headerDocument) {
                return { notFound: true };
            }
            let lineDocuments = [];
            if (includeLineDocuments) {
                const line = new this.lineModel(this.db);
                lineDocuments = yield line.findDocuments({ document_no: documentNo }, this.lineProjection);
            }
            return {
                success: true,
                data: {
                    header: headerDocument,
                    lines: lineDocuments,
                },
            };
        });
    }
}
exports.default = GetPostedDocumentByDocumentNoUseCase;
//# sourceMappingURL=get.posted.document.by.document.no.base.usecase.js.map