"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
const enum_1 = require("../../enum");
class ListUseCase {
    constructor(db, model, projection = {}, sortBy = { _id: enum_1.Sort.Desc }, filterWithBranch = true) {
        this.db = db;
        this.model = model;
        this.projection = projection;
        this.sortBy = sortBy;
        this.filterWithBranch = filterWithBranch;
    }
    exec(context, userInfo) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = new this.model(this.db);
            const skip = (context.page - 1) * context.perPage;
            const sortBy = context.sortBy || this.sortBy;
            const project = context.appliedProjection || this.projection;
            let filter = context.appliedFilter;
            if (this.filterWithBranch) {
                filter = Object.assign(Object.assign({}, filter), { branch_id: new mongodb_1.ObjectId(userInfo.current_access_branch._id) });
            }
            const documents = yield model.paginateDocument(filter, project, sortBy, skip, context.perPage);
            if (context.page < 2) {
                const countDocuments = yield model.countDocuments(filter);
                const lastPage = countDocuments <= 0 ? 0 : Math.ceil(countDocuments / context.perPage);
                return {
                    success: true,
                    data: {
                        data: documents,
                        page_context: {
                            current_page: context.page,
                            per_page: context.perPage,
                            last_page: lastPage,
                            total: countDocuments,
                        },
                    },
                };
            }
            return {
                success: true,
                data: {
                    data: documents,
                    page_context: { current_page: context.page },
                },
            };
        });
    }
}
exports.default = ListUseCase;
//# sourceMappingURL=list.base.usecase.js.map