"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const mongodb_1 = require("mongodb");
class UpdateSetupUseCase {
    constructor(db, model) {
        this.db = db;
        this.model = model;
    }
    exec(id, setupInfo) {
        return __awaiter(this, void 0, void 0, function* () {
            const model = new this.model(this.db);
            const filter = { _id: new mongodb_1.ObjectId(id) };
            const queryDocument = yield model.findOneDocument(filter);
            if (!queryDocument) {
                return { notFound: true };
            }
            if (queryDocument.has_transaction) {
                return { hasTransaction: true };
            }
            const updateDocument = model.make(setupInfo);
            updateDocument.updated_at = new Date();
            const updatedResult = yield model.updateOneDocument(updateDocument, filter, null);
            if (updatedResult.status !== 1 || updatedResult.updatedCount <= 0) {
                return {
                    failedToUpdate: true,
                };
            }
            return { success: true };
        });
    }
}
exports.default = UpdateSetupUseCase;
//# sourceMappingURL=update.setup.usecase.js.map