"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupInfoBuilder = exports.projectionBuilder = exports.filterBuilder = void 0;
const enum_1 = require("../enum");
const mongodb_1 = require("mongodb");
const utils_1 = require("./utils");
const date_1 = require("./date");
function filterBuilder(schema, value) {
    try {
        const filter = {};
        const { BETWEEN, EQUAL_TO, NOT_EQUAL_TO, GREATER_THAN, GREATER_THAN_EQUAL, LESS_THAN, LESS_THAN_EQUAL, LIKE, TEXT_SEARCH, IN, } = enum_1.ConditionFilter;
        const keys = Object.keys(value);
        keys.forEach((key) => {
            if (value[key] !== undefined && value[key] !== null && value[key] !== '') {
                if (schema[key].isDate) {
                    if (value[key].start && value[key].end) {
                        value[key].start = (0, date_1.utcDateOnly)(value[key].start);
                        value[key].end = (0, date_1.utcDateOnly)(value[key].end);
                    }
                    else {
                        value[key] = (0, date_1.utcDateOnly)(value[key]);
                    }
                }
                switch (schema[key].type) {
                    case BETWEEN:
                        filter[key] = { $gte: value[key].start, $lte: value[key].end };
                        break;
                    case EQUAL_TO:
                        filter[key] = schema[key].isObjectID ? new mongodb_1.ObjectId(value[key]) : value[key];
                        break;
                    case IN:
                        filter[key] = {
                            $in: schema[key].isObjectID ? (0, utils_1.arrayStringToArrayObjectId)(value[key]) : value[key],
                        };
                        break;
                    case NOT_EQUAL_TO:
                        filter[key] = { $ne: schema[key].isObjectID ? new mongodb_1.ObjectId(value[key]) : value[key] };
                        break;
                    case GREATER_THAN:
                        filter[key] = { $gt: value[key] };
                        break;
                    case GREATER_THAN_EQUAL:
                        filter[key] = { $gte: value[key] };
                        break;
                    case LESS_THAN:
                        filter[key] = { $lt: value[key] };
                        break;
                    case LESS_THAN_EQUAL:
                        filter[key] = { $lte: value[key] };
                        break;
                    case LIKE:
                        filter[key] = { $regex: `.*${value[key]}.*`, $options: 'i' };
                        break;
                    case TEXT_SEARCH:
                        filter[key] = { $text: { $search: value[key], $caseSensitive: false } };
                        break;
                    default:
                        break;
                }
            }
        });
        return filter;
    }
    catch (_) {
        throw Error('Invalid filter by. Try to check again.');
    }
}
exports.filterBuilder = filterBuilder;
function projectionBuilder(strFields, type = enum_1.Projection.On) {
    const fields = strFields.split(',');
    const projection = {};
    fields.forEach((field) => {
        projection[field] = type;
    });
    return projection;
}
exports.projectionBuilder = projectionBuilder;
function setupInfoBuilder(fields, value) {
    let setupInfo = {};
    fields.forEach((field) => {
        if (value[field]) {
            setupInfo[field] = value[field];
        }
        else {
            setupInfo[field] = value[field];
        }
    });
    return setupInfo;
}
exports.setupInfoBuilder = setupInfoBuilder;
//# sourceMappingURL=builder.js.map