"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.clientConnection = exports.connect = void 0;
const mongodb_1 = require("mongodb");
let cacheConnectionByDbName = {};
let cacheTransactionConnectionByDbName = {};
const mongodbClientOptions = {
    retryWrites: true,
    writeConcern: {
        w: 'majority',
        wtimeout: 5000,
    },
    readConcern: {
        level: 'majority',
    },
    readPreference: {
        mode: 'secondary',
    },
};
function createConnection(uri, options) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const client = new mongodb_1.MongoClient(uri, options);
            yield client.connect();
            return client;
        }
        catch (err) {
            throw err;
        }
    });
}
function connect(uri_1, databaseName_1) {
    return __awaiter(this, arguments, void 0, function* (uri, databaseName, options = mongodbClientOptions) {
        try {
            if (cacheConnectionByDbName[databaseName]) {
                return cacheConnectionByDbName[databaseName];
            }
            const client = yield createConnection(uri, options);
            cacheConnectionByDbName[databaseName] = client.db(databaseName);
            return cacheConnectionByDbName[databaseName];
        }
        catch (err) {
            throw err;
        }
    });
}
exports.connect = connect;
function clientConnection(uri_1, databaseName_1) {
    return __awaiter(this, arguments, void 0, function* (uri, databaseName, options = mongodbClientOptions) {
        try {
            if (cacheTransactionConnectionByDbName[databaseName]) {
                return cacheTransactionConnectionByDbName[databaseName];
            }
            const client = yield createConnection(uri, options);
            cacheTransactionConnectionByDbName[databaseName] = client;
            return client;
        }
        catch (err) {
            throw err;
        }
    });
}
exports.clientConnection = clientConnection;
//# sourceMappingURL=db.js.map