"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyPOSAuth = exports.verifyServiceAuth = exports.verifyAuth = exports.verifyAccessToken = exports.createAccessToken = void 0;
const jsonwebtoken_1 = __importDefault(require("jsonwebtoken"));
const axios_1 = __importDefault(require("axios"));
const enum_1 = require("../enum");
function createAccessToken(payload, secret, options) {
    return jsonwebtoken_1.default.sign(payload, secret, options);
}
exports.createAccessToken = createAccessToken;
function verifyAccessToken(token, secret, options) {
    try {
        return jsonwebtoken_1.default.verify(token, secret, options);
    }
    catch (error) {
        if (error.message === enum_1.JWTError.Invalid_Signature) {
            return {
                error: true,
                message: { Invalid_Signature: true },
            };
        }
        if (error.message === enum_1.JWTError.JWT_Expired) {
            return {
                error: true,
                message: { JWT_Expired: true },
            };
        }
        return {
            error: true,
            message: { JWT_Invalid: true },
        };
    }
}
exports.verifyAccessToken = verifyAccessToken;
function verifyAuth(info, authApiURL) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const res = yield axios_1.default.post(`${authApiURL}/verify`, info);
            if (res.status === enum_1.HttpCode.Ok) {
                return Object.assign({ code: res.status }, res.data.payload);
            }
            return {
                code: enum_1.HttpCode.InternalServerError,
                message: 'Something went wrong',
            };
        }
        catch (error) {
            console.log('error: ', error.message);
            return {
                code: error.response ? error.response.status : enum_1.HttpCode.InternalServerError,
                message: error.response ? error.response.data.message : 'Something went wrong',
            };
        }
    });
}
exports.verifyAuth = verifyAuth;
function verifyServiceAuth(memo, authApiURL) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const res = yield axios_1.default.post(`${authApiURL}/verify/service`, { memo });
            if (res.status === enum_1.HttpCode.Ok) {
                return Object.assign({ code: res.status }, res.data.payload);
            }
            return {
                code: enum_1.HttpCode.InternalServerError,
                message: 'Something went wrong',
            };
        }
        catch (error) {
            console.log('error: ', error.message);
            return {
                code: error.response ? error.response.status : enum_1.HttpCode.InternalServerError,
                message: error.response ? error.response.data.message : 'Something went wrong',
            };
        }
    });
}
exports.verifyServiceAuth = verifyServiceAuth;
function verifyPOSAuth(info, authApiURL) {
    return __awaiter(this, void 0, void 0, function* () {
        try {
            const res = yield axios_1.default.post(`${authApiURL}/verify/pos`, info);
            if (res.status === enum_1.HttpCode.Ok) {
                return Object.assign({ code: res.status }, res.data.payload);
            }
            return {
                code: enum_1.HttpCode.InternalServerError,
                message: 'Something went wrong',
            };
        }
        catch (error) {
            console.log('error: ', error.message);
            return {
                code: error.response ? error.response.status : enum_1.HttpCode.InternalServerError,
                message: error.response ? error.response.data.message : 'Something went wrong',
            };
        }
    });
}
exports.verifyPOSAuth = verifyPOSAuth;
//# sourceMappingURL=token.js.map