"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.memoBuilder = exports.userAccessBranchIds = exports.billingCycle = exports.taskQueueStatus = exports.isObjectHasValue = exports.currencyFormatter = exports.numberFormatter = exports.getPermission = exports.arrayStringToArrayObjectId = exports.arrayFromArrayObject = exports.numberToFixed = exports.wordFirstLetterToUpperCase = exports.decrypt = exports.encrypt = exports.comparePassword = exports.hashPassword = exports.slug = void 0;
const crypto_1 = __importDefault(require("crypto"));
const bcryptjs_1 = __importDefault(require("bcryptjs"));
const mongodb_1 = require("mongodb");
const config_1 = __importDefault(require("../config"));
const enum_1 = require("../enum");
const token_1 = require("./token");
function slug(value, sign = '-') {
    return value.replace(/\s+/g, sign).toLowerCase();
}
exports.slug = slug;
function hashPassword(password, hash) {
    const salt = bcryptjs_1.default.genSaltSync(hash);
    const hashed = bcryptjs_1.default.hashSync(password, salt);
    return hashed;
}
exports.hashPassword = hashPassword;
function comparePassword(password, hash) {
    return bcryptjs_1.default.compareSync(password, hash);
}
exports.comparePassword = comparePassword;
function encrypt(val, algorithm) {
    try {
        const _cipher = crypto_1.default.createCipheriv(algorithm, config_1.default.encryptionSK, config_1.default.encryptionSIV);
        const _encrypted = _cipher.update(val, 'utf8', 'hex') + _cipher.final('hex');
        return _encrypted;
    }
    catch (err) {
        throw err;
    }
}
exports.encrypt = encrypt;
function decrypt(val, algorithm) {
    try {
        const _decipher = crypto_1.default.createDecipheriv(algorithm, config_1.default.encryptionSK, config_1.default.encryptionSIV);
        const _decrypted = _decipher.update(val, 'hex', 'utf8') + _decipher.final('utf8');
        return _decrypted;
    }
    catch (err) {
        throw err;
    }
}
exports.decrypt = decrypt;
function wordFirstLetterToUpperCase(str) {
    let splitStr = str.toLowerCase().split(' ');
    for (let i = 0; i < splitStr.length; i++) {
        splitStr[i] = splitStr[i].charAt(0).toUpperCase() + splitStr[i].substring(1);
    }
    return splitStr.join(' ');
}
exports.wordFirstLetterToUpperCase = wordFirstLetterToUpperCase;
function numberToFixed(val, fractionDigits) {
    return parseFloat(parseFloat(val.toString()).toFixed(fractionDigits));
}
exports.numberToFixed = numberToFixed;
const arrayFromArrayObject = (arrayObject, fieldToExtract, isObjectID = false) => {
    const arrValue = arrayObject.map((arr) => {
        if (isObjectID) {
            return new mongodb_1.ObjectId(arr[fieldToExtract]);
        }
        return arr[fieldToExtract];
    });
    return arrValue;
};
exports.arrayFromArrayObject = arrayFromArrayObject;
function arrayStringToArrayObjectId(value) {
    return value.map((str) => new mongodb_1.ObjectId(str));
}
exports.arrayStringToArrayObjectId = arrayStringToArrayObjectId;
function getPermission(option) {
    const { appId, userRole, type, code, subCode } = option;
    if ([config_1.default.inventoryAppId, config_1.default.billingAppId, config_1.default.loyaltyAppId, config_1.default.restaurantAppId].includes(appId)) {
        if (type === enum_1.PermissionType.Report && 'reports' in userRole.permission) {
            if (!subCode)
                return null;
            const report = userRole.permission.reports.find((roleReport) => roleReport.report_code === code);
            if (!report)
                return null;
            return report.sub.find((subReport) => subReport.report_code === subCode);
        }
        else if (type === enum_1.PermissionType.Setting && 'settings' in userRole.permission) {
            return userRole.permission.settings.find((roleSetting) => roleSetting.setting_code === code);
        }
        else {
            return userRole.permission[type].find((roleMenu) => roleMenu.menu_code === code);
        }
    }
    return null;
}
exports.getPermission = getPermission;
function numberFormatter(value, options, locales) {
    return new Intl.NumberFormat(locales || undefined, options).format(value);
}
exports.numberFormatter = numberFormatter;
function currencyFormatter(value, currencyCode, options, locales) {
    const valueFormatted = numberFormatter(value, options, locales);
    return `${currencyCode} ${valueFormatted}`;
}
exports.currencyFormatter = currencyFormatter;
function isObjectHasValue(obj) {
    return Object.values(obj).length > 0;
}
exports.isObjectHasValue = isObjectHasValue;
function taskQueueStatus(code) {
    switch (code) {
        case enum_1.TaskQueueStatusCode.Queue:
            return enum_1.TaskQueueStatus.Queue;
        case enum_1.TaskQueueStatusCode.Processing:
            return enum_1.TaskQueueStatus.Processing;
        case enum_1.TaskQueueStatusCode.Failed:
            return enum_1.TaskQueueStatus.Failed;
        default:
            return enum_1.TaskQueueStatus.Queue;
    }
}
exports.taskQueueStatus = taskQueueStatus;
function billingCycle(code) {
    switch (code) {
        case enum_1.BillingCycleCode.Onetime:
            return enum_1.BillingCycle.Onetime;
        case enum_1.BillingCycleCode.Recurring:
            return enum_1.BillingCycle.Recurring;
        default:
            return enum_1.BillingCycle.Onetime;
    }
}
exports.billingCycle = billingCycle;
const userAccessBranchIds = (userAccessBranches) => {
    const branchIds = [];
    for (const userAccessBranch of userAccessBranches) {
        branchIds.push(new mongodb_1.ObjectId(userAccessBranch._id));
    }
    return branchIds;
};
exports.userAccessBranchIds = userAccessBranchIds;
const memoBuilder = (arrStr, secret) => {
    const memo = (0, token_1.createAccessToken)(arrStr.join(':'), secret);
    return memo;
};
exports.memoBuilder = memoBuilder;
//# sourceMappingURL=utils.js.map